{-# LANGUAGE MagicHash #-}
{-# LANGUAGE ScopedTypeVariables #-}
{-# LANGUAGE QuantifiedConstraints #-}
{-# LANGUAGE RankNTypes #-}
{-# LANGUAGE PolyKinds #-}
{-# LANGUAGE MultiParamTypeClasses #-}
{-# LANGUAGE FlexibleInstances #-}
{-# LANGUAGE CPP #-}
{-# OPTIONS_GHC -fno-warn-overlapping-patterns #-}
{-# OPTIONS_GHC -fno-warn-missing-methods #-}
#if __GLASGOW_HASKELL__ >= 800
{-# OPTIONS_GHC -fno-warn-redundant-constraints #-}
#else
{-# OPTIONS_GHC -fno-warn-duplicate-constraints #-}
#endif

module Analysis.Curry_Indeterministic
  ( d_C_indetAnalysis, nd_C_indetAnalysis, d_C_showIndet )
  where

import Basics
import qualified Analysis.Curry_Types
import qualified FlatCurry.Curry_Types
import qualified Curry_Prelude


d_C_indetAnalysis :: Cover -> ConstStore -> Analysis.Curry_Types.C_Analysis
  Curry_Prelude.C_Bool
d_C_indetAnalysis cd cs = Analysis.Curry_Types.d_C_dependencyFuncAnalysis
  (Curry_Prelude.toCurryString "Indeterministic") Curry_Prelude.C_False
  (acceptCs id d_C_indetFunc) cd cs

nd_C_indetAnalysis :: IDSupply -> Cover -> ConstStore
  -> Analysis.Curry_Types.C_Analysis Curry_Prelude.C_Bool
nd_C_indetAnalysis s cd cs = let s0 = s
  in s0 `seq` Analysis.Curry_Types.nd_C_dependencyFuncAnalysis
  (Curry_Prelude.toCurryString "Indeterministic") Curry_Prelude.C_False (wrapDX
  (wrapDX id) (acceptCs id d_C_indetFunc)) s0 cd cs

d_C_indetFunc :: FlatCurry.Curry_Types.C_FuncDecl -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) (Curry_Prelude.OP_List Curry_Prelude.C_Char))
  Curry_Prelude.C_Bool) -> Cover -> ConstStore -> Curry_Prelude.C_Bool
d_C_indetFunc x1 x2 cd cs = Curry_Prelude.d_OP_bar_bar (d_C_hasIndetRules x1 cd
  cs) (Curry_Prelude.d_C_apply (Curry_Prelude.d_C_any Curry_Prelude.d_C_snd cd
  cs) x2 cd cs) cd cs

d_C_showIndet :: Analysis.Curry_Types.C_AOutFormat -> Curry_Prelude.C_Bool
  -> Cover -> ConstStore -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C_showIndet x1 x2 cd cs = case x1 of
  Analysis.Curry_Types.C_AText -> d_C__case_2 x2 cd cs
  Analysis.Curry_Types.C_ANote -> d_C__case_1 x2 cd cs
  Analysis.Curry_Types.Choice_C_AOutFormat d i l r -> narrow d i (d_C_showIndet
    l x2 cd cs) (d_C_showIndet r x2 cd cs)
  Analysis.Curry_Types.Choices_C_AOutFormat d i xs -> narrows cs d i (\z ->
    d_C_showIndet z x2 cd cs) xs
  Analysis.Curry_Types.Guard_C_AOutFormat d c e -> guardCons d c ((\x ->
    d_C_showIndet e x2 cd x) $! addCs c cs)
  Analysis.Curry_Types.Fail_C_AOutFormat d info -> failCons d (traceFail
    "Analysis.Indeterministic.showIndet" [show x1, show x2] info)
  _ -> failCons cd (consFail "Analysis.Indeterministic.showIndet" (showCons x1))

d_C_hasIndetRules :: FlatCurry.Curry_Types.C_FuncDecl -> Cover -> ConstStore
  -> Curry_Prelude.C_Bool
d_C_hasIndetRules x1 cd cs = case x1 of
  FlatCurry.Curry_Types.C_Func x2 x3 x4 x5 x6 -> d_C__case_0 x6 cd cs
  FlatCurry.Curry_Types.Choice_C_FuncDecl d i l r -> narrow d i
    (d_C_hasIndetRules l cd cs) (d_C_hasIndetRules r cd cs)
  FlatCurry.Curry_Types.Choices_C_FuncDecl d i xs -> narrows cs d i (\z ->
    d_C_hasIndetRules z cd cs) xs
  FlatCurry.Curry_Types.Guard_C_FuncDecl d c e -> guardCons d c ((\x ->
    d_C_hasIndetRules e cd x) $! addCs c cs)
  FlatCurry.Curry_Types.Fail_C_FuncDecl d info -> failCons d (traceFail
    "Analysis.Indeterministic.hasIndetRules" [show x1] info)
  _ -> failCons cd (consFail "Analysis.Indeterministic.hasIndetRules" (showCons
    x1))

d_C_indetInExpr :: FlatCurry.Curry_Types.C_Expr -> Cover -> ConstStore
  -> Curry_Prelude.C_Bool
d_C_indetInExpr x1 cd cs = case x1 of
  FlatCurry.Curry_Types.C_Var x2 -> Curry_Prelude.C_False
  FlatCurry.Curry_Types.C_Lit x3 -> Curry_Prelude.C_False
  FlatCurry.Curry_Types.C_Comb x4 x5 x6 -> Curry_Prelude.d_OP_bar_bar
    (d_C_isIndetFunction x5 cd cs) (Curry_Prelude.d_C_apply
    (Curry_Prelude.d_C_any d_C_indetInExpr cd cs) x6 cd cs) cd cs
  FlatCurry.Curry_Types.C_Free x7 x8 -> d_C_indetInExpr x8 cd cs
  FlatCurry.Curry_Types.C_Let x9 x10 -> Curry_Prelude.d_OP_bar_bar
    (Curry_Prelude.d_C_apply (Curry_Prelude.d_C_any d_C_indetInExpr cd cs)
    (Curry_Prelude.d_C_map Curry_Prelude.d_C_snd x9 cd cs) cd cs)
    (d_C_indetInExpr x10 cd cs) cd cs
  FlatCurry.Curry_Types.C_Or x11 x12 -> Curry_Prelude.d_OP_bar_bar
    (d_C_indetInExpr x11 cd cs) (d_C_indetInExpr x12 cd cs) cd cs
  FlatCurry.Curry_Types.C_Case x13 x14 x15 -> Curry_Prelude.d_OP_bar_bar
    (d_C_indetInExpr x14 cd cs) (Curry_Prelude.d_C_apply (Curry_Prelude.d_C_any
    d_OP_indetInExpr_dot_indetInBranch_dot_45 cd cs) x15 cd cs) cd cs
  FlatCurry.Curry_Types.C_Typed x16 x17 -> d_C_indetInExpr x16 cd cs
  FlatCurry.Curry_Types.Choice_C_Expr d i l r -> narrow d i (d_C_indetInExpr l
    cd cs) (d_C_indetInExpr r cd cs)
  FlatCurry.Curry_Types.Choices_C_Expr d i xs -> narrows cs d i (\z ->
    d_C_indetInExpr z cd cs) xs
  FlatCurry.Curry_Types.Guard_C_Expr d c e -> guardCons d c ((\x ->
    d_C_indetInExpr e cd x) $! addCs c cs)
  FlatCurry.Curry_Types.Fail_C_Expr d info -> failCons d (traceFail
    "Analysis.Indeterministic.indetInExpr" [show x1] info)
  _ -> failCons cd (consFail "Analysis.Indeterministic.indetInExpr" (showCons
    x1))

d_OP_indetInExpr_dot_indetInBranch_dot_45 :: FlatCurry.Curry_Types.C_BranchExpr
  -> Cover -> ConstStore -> Curry_Prelude.C_Bool
d_OP_indetInExpr_dot_indetInBranch_dot_45 x1 cd cs = case x1 of
  FlatCurry.Curry_Types.C_Branch x2 x3 -> d_C_indetInExpr x3 cd cs
  FlatCurry.Curry_Types.Choice_C_BranchExpr d i l r -> narrow d i
    (d_OP_indetInExpr_dot_indetInBranch_dot_45 l cd cs)
    (d_OP_indetInExpr_dot_indetInBranch_dot_45 r cd cs)
  FlatCurry.Curry_Types.Choices_C_BranchExpr d i xs -> narrows cs d i (\z ->
    d_OP_indetInExpr_dot_indetInBranch_dot_45 z cd cs) xs
  FlatCurry.Curry_Types.Guard_C_BranchExpr d c e -> guardCons d c ((\x ->
    d_OP_indetInExpr_dot_indetInBranch_dot_45 e cd x) $! addCs c cs)
  FlatCurry.Curry_Types.Fail_C_BranchExpr d info -> failCons d (traceFail
    "Analysis.Indeterministic.indetInExpr.indetInBranch.45" [show x1] info)
  _ -> failCons cd (consFail
    "Analysis.Indeterministic.indetInExpr.indetInBranch.45" (showCons x1))

d_C_isIndetFunction :: Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Cover
  -> ConstStore -> Curry_Prelude.C_Bool
d_C_isIndetFunction x1 cd cs = case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> Curry_Prelude.d_OP_bar_bar
    (Curry_Prelude.d_OP_amp_amp (Curry_Prelude.d_C_apply (Curry_Prelude.d_C_elem
    (Curry_Prelude.d_OP_uscore_inst_hash_Prelude_dot_Eq_hash_lbracket_rbracket_hash_0_hash_hash
    Curry_Prelude.d_OP_uscore_inst_hash_Prelude_dot_Eq_hash_Prelude_dot_Char_hash)
    x2 cd cs) (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
    "Control.Search.SetFunctions") (Curry_Prelude.OP_Cons
    (Curry_Prelude.toCurryString "Control.SetFunctions") Curry_Prelude.OP_List))
    cd cs) (Curry_Prelude.d_C_apply (Curry_Prelude.d_C_elem
    (Curry_Prelude.d_OP_uscore_inst_hash_Prelude_dot_Eq_hash_lbracket_rbracket_hash_0_hash_hash
    Curry_Prelude.d_OP_uscore_inst_hash_Prelude_dot_Eq_hash_Prelude_dot_Char_hash)
    x3 cd cs) (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString "select")
    (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString "selectValue")
    Curry_Prelude.OP_List)) cd cs) cd cs) (Curry_Prelude.d_OP_bar_bar
    (Curry_Prelude.d_C_apply (Curry_Prelude.d_C_elem
    (Curry_Prelude.d_OP_uscore_inst_hash_Prelude_dot_Eq_hash_lbracket_rbracket_hash_0_hash_hash
    Curry_Prelude.d_OP_uscore_inst_hash_Prelude_dot_Eq_hash_Prelude_dot_Char_hash)
    x2 cd cs) (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
    "System.IO.Unsafe") (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
    "Control.Search.Unsafe") (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
    "Control.AllValues") (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
    "Control.Findall") (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
    "Control.Search.SearchTree.Unsafe") Curry_Prelude.OP_List))))) cd cs)
    (Curry_Prelude.d_OP_amp_amp
    (Curry_Prelude.d_OP_uscore_impl_hash_eq_eq_hash_Prelude_dot_Eq_hash_lbracket_rbracket_hash_0_hash_hash
    Curry_Prelude.d_OP_uscore_inst_hash_Prelude_dot_Eq_hash_Prelude_dot_Char_hash
    x2 (Curry_Prelude.toCurryString "Network.Ports") cd cs)
    (Curry_Prelude.d_C_apply (Curry_Prelude.d_C_elem
    (Curry_Prelude.d_OP_uscore_inst_hash_Prelude_dot_Eq_hash_lbracket_rbracket_hash_0_hash_hash
    Curry_Prelude.d_OP_uscore_inst_hash_Prelude_dot_Eq_hash_Prelude_dot_Char_hash)
    x3 cd cs) (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString "send")
    (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString "timeoutOnStream")
    (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString "choiceSPEP")
    Curry_Prelude.OP_List))) cd cs) cd cs) cd cs) cd cs
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i (d_C_isIndetFunction l cd
    cs) (d_C_isIndetFunction r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    d_C_isIndetFunction z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c ((\x ->
    d_C_isIndetFunction e cd x) $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "Analysis.Indeterministic.isIndetFunction" [show x1] info)
  _ -> failCons cd (consFail "Analysis.Indeterministic.isIndetFunction"
    (showCons x1))

d_C__case_1 :: Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C__case_1 x2 cd cs = case x2 of
  Curry_Prelude.C_True -> Curry_Prelude.toCurryString "indeterministic"
  Curry_Prelude.C_False -> Curry_Prelude.OP_List
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_1 l cd cs)
    (d_C__case_1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_1 z cd
    cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c ((\x -> d_C__case_1 e cd
    x) $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "Analysis.Indeterministic._case_1" [show x2] info)
  _ -> failCons cd (consFail "Analysis.Indeterministic._case_1" (showCons x2))

d_C__case_2 :: Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C__case_2 x2 cd cs = case x2 of
  Curry_Prelude.C_True -> Curry_Prelude.toCurryString
    "impure (indeterministic) operation"
  Curry_Prelude.C_False -> Curry_Prelude.toCurryString
    "referentially transparent operation"
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_2 l cd cs)
    (d_C__case_2 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_2 z cd
    cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c ((\x -> d_C__case_2 e cd
    x) $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "Analysis.Indeterministic._case_2" [show x2] info)
  _ -> failCons cd (consFail "Analysis.Indeterministic._case_2" (showCons x2))

d_C__case_0 :: FlatCurry.Curry_Types.C_Rule -> Cover -> ConstStore
  -> Curry_Prelude.C_Bool
d_C__case_0 x6 cd cs = case x6 of
  FlatCurry.Curry_Types.C_Rule x7 x8 -> d_C_indetInExpr x8 cd cs
  FlatCurry.Curry_Types.C_External x9 -> Curry_Prelude.C_False
  FlatCurry.Curry_Types.Choice_C_Rule d i l r -> narrow d i (d_C__case_0 l cd
    cs) (d_C__case_0 r cd cs)
  FlatCurry.Curry_Types.Choices_C_Rule d i xs -> narrows cs d i (\z ->
    d_C__case_0 z cd cs) xs
  FlatCurry.Curry_Types.Guard_C_Rule d c e -> guardCons d c ((\x -> d_C__case_0
    e cd x) $! addCs c cs)
  FlatCurry.Curry_Types.Fail_C_Rule d info -> failCons d (traceFail
    "Analysis.Indeterministic._case_0" [show x6] info)
  _ -> failCons cd (consFail "Analysis.Indeterministic._case_0" (showCons x6))

