{-# LANGUAGE MagicHash #-}
{-# LANGUAGE ScopedTypeVariables #-}
{-# LANGUAGE QuantifiedConstraints #-}
{-# LANGUAGE RankNTypes #-}
{-# LANGUAGE PolyKinds #-}
{-# LANGUAGE MultiParamTypeClasses #-}
{-# LANGUAGE FlexibleInstances #-}
{-# LANGUAGE CPP #-}
{-# OPTIONS_GHC -fno-warn-overlapping-patterns #-}
{-# OPTIONS_GHC -fno-warn-missing-methods #-}
#if __GLASGOW_HASKELL__ >= 800
{-# OPTIONS_GHC -fno-warn-redundant-constraints #-}
#else
{-# OPTIONS_GHC -fno-warn-duplicate-constraints #-}
#endif

module Analysis.Curry_RightLinearity
  ( d_C_rlinAnalysis
  , nd_C_rlinAnalysis
  , d_C_showRightLinear
  , d_C_hasRightLinearRules
  , d_C_linearExpr )
  where

import Basics
import qualified Analysis.Curry_Types
import qualified Data.Curry_List
import qualified FlatCurry.Curry_Types
import qualified Curry_Prelude


d_C_rlinAnalysis :: Cover -> ConstStore -> Analysis.Curry_Types.C_Analysis
  Curry_Prelude.C_Bool
d_C_rlinAnalysis cd cs = Analysis.Curry_Types.d_C_dependencyFuncAnalysis
  (Curry_Prelude.toCurryString "RightLinear") Curry_Prelude.C_True (acceptCs id
  d_C_rlFunc) cd cs

nd_C_rlinAnalysis :: IDSupply -> Cover -> ConstStore
  -> Analysis.Curry_Types.C_Analysis Curry_Prelude.C_Bool
nd_C_rlinAnalysis s cd cs = let s0 = s
  in s0 `seq` Analysis.Curry_Types.nd_C_dependencyFuncAnalysis
  (Curry_Prelude.toCurryString "RightLinear") Curry_Prelude.C_True (wrapDX
  (wrapDX id) (acceptCs id d_C_rlFunc)) s0 cd cs

d_C_rlFunc :: FlatCurry.Curry_Types.C_FuncDecl -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) (Curry_Prelude.OP_List Curry_Prelude.C_Char))
  Curry_Prelude.C_Bool) -> Cover -> ConstStore -> Curry_Prelude.C_Bool
d_C_rlFunc x1 x2 cd cs = Curry_Prelude.d_OP_amp_amp (d_C_hasRightLinearRules x1
  cd cs) (Curry_Prelude.d_C_apply (Curry_Prelude.d_C_all Curry_Prelude.d_C_snd
  cd cs) x2 cd cs) cd cs

d_C_showRightLinear :: Analysis.Curry_Types.C_AOutFormat -> Curry_Prelude.C_Bool
  -> Cover -> ConstStore -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C_showRightLinear x1 x2 cd cs = case x2 of
  Curry_Prelude.C_True -> Curry_Prelude.toCurryString "right-linear"
  Curry_Prelude.C_False -> d_C__case_6 x1 cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C_showRightLinear x1 l cd
    cs) (d_C_showRightLinear x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z ->
    d_C_showRightLinear x1 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c ((\x -> d_C_showRightLinear
    x1 e cd x) $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "Analysis.RightLinearity.showRightLinear" [show x1, show x2] info)
  _ -> failCons cd (consFail "Analysis.RightLinearity.showRightLinear" (showCons
    x2))

d_C_hasRightLinearRules :: FlatCurry.Curry_Types.C_FuncDecl -> Cover
  -> ConstStore -> Curry_Prelude.C_Bool
d_C_hasRightLinearRules x1 cd cs = case x1 of
  FlatCurry.Curry_Types.C_Func x2 x3 x4 x5 x6 -> d_C_isRightLinearRule x6 cd cs
  FlatCurry.Curry_Types.Choice_C_FuncDecl d i l r -> narrow d i
    (d_C_hasRightLinearRules l cd cs) (d_C_hasRightLinearRules r cd cs)
  FlatCurry.Curry_Types.Choices_C_FuncDecl d i xs -> narrows cs d i (\z ->
    d_C_hasRightLinearRules z cd cs) xs
  FlatCurry.Curry_Types.Guard_C_FuncDecl d c e -> guardCons d c ((\x ->
    d_C_hasRightLinearRules e cd x) $! addCs c cs)
  FlatCurry.Curry_Types.Fail_C_FuncDecl d info -> failCons d (traceFail
    "Analysis.RightLinearity.hasRightLinearRules" [show x1] info)
  _ -> failCons cd (consFail "Analysis.RightLinearity.hasRightLinearRules"
    (showCons x1))

d_C_isRightLinearRule :: FlatCurry.Curry_Types.C_Rule -> Cover -> ConstStore
  -> Curry_Prelude.C_Bool
d_C_isRightLinearRule x1 cd cs = case x1 of
  FlatCurry.Curry_Types.C_Rule x2 x3 -> d_C_linearExpr x3 cd cs
  FlatCurry.Curry_Types.C_External x4 -> Curry_Prelude.C_True
  FlatCurry.Curry_Types.Choice_C_Rule d i l r -> narrow d i
    (d_C_isRightLinearRule l cd cs) (d_C_isRightLinearRule r cd cs)
  FlatCurry.Curry_Types.Choices_C_Rule d i xs -> narrows cs d i (\z ->
    d_C_isRightLinearRule z cd cs) xs
  FlatCurry.Curry_Types.Guard_C_Rule d c e -> guardCons d c ((\x ->
    d_C_isRightLinearRule e cd x) $! addCs c cs)
  FlatCurry.Curry_Types.Fail_C_Rule d info -> failCons d (traceFail
    "Analysis.RightLinearity.isRightLinearRule" [show x1] info)
  _ -> failCons cd (consFail "Analysis.RightLinearity.isRightLinearRule"
    (showCons x1))

d_C_linearExpr :: FlatCurry.Curry_Types.C_Expr -> Cover -> ConstStore
  -> Curry_Prelude.C_Bool
d_C_linearExpr x1 cd cs = Curry_Prelude.d_C_maybe Curry_Prelude.C_False
  (Curry_Prelude.d_C_const Curry_Prelude.C_True) (d_C_linearVariables x1 cd cs)
  cd cs

d_C_linearVariables :: FlatCurry.Curry_Types.C_Expr -> Cover -> ConstStore
  -> Curry_Prelude.C_Maybe (Curry_Prelude.OP_List Curry_Prelude.C_Int)
d_C_linearVariables x1 cd cs = case x1 of
  FlatCurry.Curry_Types.C_Var x2 -> Curry_Prelude.C_Just (Curry_Prelude.OP_Cons
    x2 Curry_Prelude.OP_List)
  FlatCurry.Curry_Types.C_Lit x3 -> Curry_Prelude.C_Just Curry_Prelude.OP_List
  FlatCurry.Curry_Types.C_Comb x4 x5 x6 -> d_C__case_5 x6 x5
    (Curry_Prelude.d_OP_amp_amp
    (Curry_Prelude.d_OP_uscore_impl_hash_eq_eq_hash_Prelude_dot_Eq_hash_lparen_comma_rparen_hash_0_hash_hash_1_hash_hash
    (Curry_Prelude.d_OP_uscore_inst_hash_Prelude_dot_Eq_hash_lbracket_rbracket_hash_0_hash_hash
    Curry_Prelude.d_OP_uscore_inst_hash_Prelude_dot_Eq_hash_Prelude_dot_Char_hash)
    (Curry_Prelude.d_OP_uscore_inst_hash_Prelude_dot_Eq_hash_lbracket_rbracket_hash_0_hash_hash
    Curry_Prelude.d_OP_uscore_inst_hash_Prelude_dot_Eq_hash_Prelude_dot_Char_hash)
    x5 (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString "Prelude")
    (Curry_Prelude.toCurryString "?")) cd cs)
    (Curry_Prelude.d_OP_uscore_impl_hash_eq_eq_hash_Prelude_dot_Eq_hash_Prelude_dot_Int_hash
    (Curry_Prelude.d_C_length x6 cd cs) (Curry_Prelude.C_Int (2)) cd cs) cd cs)
    cd cs
  FlatCurry.Curry_Types.C_Free x7 x8 -> Curry_Prelude.d_OP_uscore_impl_hash_gt_gt_eq_hash_Prelude_dot_Monad_hash_Prelude_dot_Maybe_hash
    (d_C_linearVariables x8 cd cs) (d_OP_linearVariables_dot_uscore_hash_lambda2
    x7) cd cs
  FlatCurry.Curry_Types.C_Let x9 x10 -> Curry_Prelude.d_OP_uscore_impl_hash_gt_gt_eq_hash_Prelude_dot_Monad_hash_Prelude_dot_Maybe_hash
    (Curry_Prelude.d_C_apply (Curry_Prelude.d_C_mapM
    Curry_Prelude.d_OP_uscore_inst_hash_Prelude_dot_Monad_hash_Prelude_dot_Maybe_hash
    d_C_linearVariables cd cs) (Curry_Prelude.d_C_map Curry_Prelude.d_C_snd x9
    cd cs) cd cs) (d_OP_linearVariables_dot_uscore_hash_lambda3 x10 x9) cd cs
  FlatCurry.Curry_Types.C_Or x11 x12 -> Curry_Prelude.d_OP_uscore_impl_hash_gt_gt_eq_hash_Prelude_dot_Monad_hash_Prelude_dot_Maybe_hash
    (d_C_linearVariables x11 cd cs)
    (d_OP_linearVariables_dot_uscore_hash_lambda5 x12) cd cs
  FlatCurry.Curry_Types.C_Case x13 x14 x15 -> Curry_Prelude.d_OP_uscore_impl_hash_gt_gt_eq_hash_Prelude_dot_Monad_hash_Prelude_dot_Maybe_hash
    (d_C_linearVariables x14 cd cs)
    (d_OP_linearVariables_dot_uscore_hash_lambda7 x15) cd cs
  FlatCurry.Curry_Types.C_Typed x16 x17 -> d_C_linearVariables x16 cd cs
  FlatCurry.Curry_Types.Choice_C_Expr d i l r -> narrow d i (d_C_linearVariables
    l cd cs) (d_C_linearVariables r cd cs)
  FlatCurry.Curry_Types.Choices_C_Expr d i xs -> narrows cs d i (\z ->
    d_C_linearVariables z cd cs) xs
  FlatCurry.Curry_Types.Guard_C_Expr d c e -> guardCons d c ((\x ->
    d_C_linearVariables e cd x) $! addCs c cs)
  FlatCurry.Curry_Types.Fail_C_Expr d info -> failCons d (traceFail
    "Analysis.RightLinearity.linearVariables" [show x1] info)
  _ -> failCons cd (consFail "Analysis.RightLinearity.linearVariables" (showCons
    x1))

d_OP_linearVariables_dot_uscore_hash_lambda1 :: Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Int) -> Cover -> ConstStore
  -> Curry_Prelude.C_Maybe (Curry_Prelude.OP_List Curry_Prelude.C_Int)
d_OP_linearVariables_dot_uscore_hash_lambda1 x1 cd cs =
  let x2 = Curry_Prelude.d_C_apply (Curry_Prelude.d_C_concat cd cs) x1 cd cs
  in d_C__case_3 x2
  (Curry_Prelude.d_OP_uscore_impl_hash_eq_eq_hash_Prelude_dot_Eq_hash_lbracket_rbracket_hash_0_hash_hash
  Curry_Prelude.d_OP_uscore_inst_hash_Prelude_dot_Eq_hash_Prelude_dot_Int_hash
  (Data.Curry_List.d_C_nub
  Curry_Prelude.d_OP_uscore_inst_hash_Prelude_dot_Eq_hash_Prelude_dot_Int_hash
  x2 cd cs) x2 cd cs) cd cs

d_OP_linearVariables_dot_uscore_hash_lambda2 :: Curry_Prelude.OP_List
  Curry_Prelude.C_Int -> Curry_Prelude.OP_List Curry_Prelude.C_Int -> Cover
  -> ConstStore -> Curry_Prelude.C_Maybe (Curry_Prelude.OP_List
  Curry_Prelude.C_Int)
d_OP_linearVariables_dot_uscore_hash_lambda2 x1 x2 cd cs = Curry_Prelude.C_Just
  (Data.Curry_List.d_OP_backslash_backslash
  Curry_Prelude.d_OP_uscore_inst_hash_Prelude_dot_Eq_hash_Prelude_dot_Int_hash
  x2 x1 cd cs)

d_OP_linearVariables_dot_uscore_hash_lambda3 :: FlatCurry.Curry_Types.C_Expr
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 Curry_Prelude.C_Int
  FlatCurry.Curry_Types.C_Expr) -> Curry_Prelude.OP_List (Curry_Prelude.OP_List
  Curry_Prelude.C_Int) -> Cover -> ConstStore -> Curry_Prelude.C_Maybe
  (Curry_Prelude.OP_List Curry_Prelude.C_Int)
d_OP_linearVariables_dot_uscore_hash_lambda3 x1 x2 x3 cd cs =
  Curry_Prelude.d_OP_uscore_impl_hash_gt_gt_eq_hash_Prelude_dot_Monad_hash_Prelude_dot_Maybe_hash
  (d_C_linearVariables x1 cd cs)
  (d_OP_linearVariables_dot_uscore_hash_lambda3_dot_uscore_hash_lambda4 x3 x2)
  cd cs

d_OP_linearVariables_dot_uscore_hash_lambda3_dot_uscore_hash_lambda4 :: Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Int) -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_Tuple2 Curry_Prelude.C_Int FlatCurry.Curry_Types.C_Expr)
  -> Curry_Prelude.OP_List Curry_Prelude.C_Int -> Cover -> ConstStore
  -> Curry_Prelude.C_Maybe (Curry_Prelude.OP_List Curry_Prelude.C_Int)
d_OP_linearVariables_dot_uscore_hash_lambda3_dot_uscore_hash_lambda4 x1 x2 x3 cd cs =
  let x4 = Curry_Prelude.d_C_apply (Curry_Prelude.d_C_concat cd cs)
        (Curry_Prelude.OP_Cons x3 x1) cd cs
  in d_C__case_2 x4 x2
  (Curry_Prelude.d_OP_uscore_impl_hash_eq_eq_hash_Prelude_dot_Eq_hash_lbracket_rbracket_hash_0_hash_hash
  Curry_Prelude.d_OP_uscore_inst_hash_Prelude_dot_Eq_hash_Prelude_dot_Int_hash
  (Data.Curry_List.d_C_nub
  Curry_Prelude.d_OP_uscore_inst_hash_Prelude_dot_Eq_hash_Prelude_dot_Int_hash
  x4 cd cs) x4 cd cs) cd cs

d_OP_linearVariables_dot_uscore_hash_lambda5 :: FlatCurry.Curry_Types.C_Expr
  -> Curry_Prelude.OP_List Curry_Prelude.C_Int -> Cover -> ConstStore
  -> Curry_Prelude.C_Maybe (Curry_Prelude.OP_List Curry_Prelude.C_Int)
d_OP_linearVariables_dot_uscore_hash_lambda5 x1 x2 cd cs =
  Curry_Prelude.d_OP_uscore_impl_hash_gt_gt_eq_hash_Prelude_dot_Monad_hash_Prelude_dot_Maybe_hash
  (d_C_linearVariables x1 cd cs)
  (d_OP_linearVariables_dot_uscore_hash_lambda5_dot_uscore_hash_lambda6 x2) cd
  cs

d_OP_linearVariables_dot_uscore_hash_lambda5_dot_uscore_hash_lambda6 :: Curry_Prelude.OP_List
  Curry_Prelude.C_Int -> Curry_Prelude.OP_List Curry_Prelude.C_Int -> Cover
  -> ConstStore -> Curry_Prelude.C_Maybe (Curry_Prelude.OP_List
  Curry_Prelude.C_Int)
d_OP_linearVariables_dot_uscore_hash_lambda5_dot_uscore_hash_lambda6 x1 x2 cd cs =
  Curry_Prelude.C_Just (Data.Curry_List.d_C_union
  Curry_Prelude.d_OP_uscore_inst_hash_Prelude_dot_Eq_hash_Prelude_dot_Int_hash
  x1 x2 cd cs)

d_OP_linearVariables_dot_patternVars_dot_52 :: FlatCurry.Curry_Types.C_BranchExpr
  -> Cover -> ConstStore -> Curry_Prelude.OP_List Curry_Prelude.C_Int
d_OP_linearVariables_dot_patternVars_dot_52 x1 cd cs = case x1 of
  FlatCurry.Curry_Types.C_Branch x2 x3 -> d_C__case_1 x2 cd cs
  FlatCurry.Curry_Types.Choice_C_BranchExpr d i l r -> narrow d i
    (d_OP_linearVariables_dot_patternVars_dot_52 l cd cs)
    (d_OP_linearVariables_dot_patternVars_dot_52 r cd cs)
  FlatCurry.Curry_Types.Choices_C_BranchExpr d i xs -> narrows cs d i (\z ->
    d_OP_linearVariables_dot_patternVars_dot_52 z cd cs) xs
  FlatCurry.Curry_Types.Guard_C_BranchExpr d c e -> guardCons d c ((\x ->
    d_OP_linearVariables_dot_patternVars_dot_52 e cd x) $! addCs c cs)
  FlatCurry.Curry_Types.Fail_C_BranchExpr d info -> failCons d (traceFail
    "Analysis.RightLinearity.linearVariables.patternVars.52" [show x1] info)
  _ -> failCons cd (consFail
    "Analysis.RightLinearity.linearVariables.patternVars.52" (showCons x1))

d_OP_linearVariables_dot_uscore_hash_lambda7 :: Curry_Prelude.OP_List
  FlatCurry.Curry_Types.C_BranchExpr -> Curry_Prelude.OP_List
  Curry_Prelude.C_Int -> Cover -> ConstStore -> Curry_Prelude.C_Maybe
  (Curry_Prelude.OP_List Curry_Prelude.C_Int)
d_OP_linearVariables_dot_uscore_hash_lambda7 x1 x2 cd cs =
  Curry_Prelude.d_OP_uscore_impl_hash_gt_gt_eq_hash_Prelude_dot_Monad_hash_Prelude_dot_Maybe_hash
  (Curry_Prelude.d_C_apply (Curry_Prelude.d_C_mapM
  Curry_Prelude.d_OP_uscore_inst_hash_Prelude_dot_Monad_hash_Prelude_dot_Maybe_hash
  d_C_linearVariables cd cs) (Curry_Prelude.d_C_map
  d_OP_linearVariables_dot_uscore_hash_lambda7_dot_uscore_hash_lambda8 x1 cd cs)
  cd cs) (d_OP_linearVariables_dot_uscore_hash_lambda7_dot_uscore_hash_lambda9
  x1 x2) cd cs

d_OP_linearVariables_dot_uscore_hash_lambda7_dot_uscore_hash_lambda8 :: FlatCurry.Curry_Types.C_BranchExpr
  -> Cover -> ConstStore -> FlatCurry.Curry_Types.C_Expr
d_OP_linearVariables_dot_uscore_hash_lambda7_dot_uscore_hash_lambda8 x1 cd cs =
  case x1 of
  FlatCurry.Curry_Types.C_Branch x2 x3 -> x3
  FlatCurry.Curry_Types.Choice_C_BranchExpr d i l r -> narrow d i
    (d_OP_linearVariables_dot_uscore_hash_lambda7_dot_uscore_hash_lambda8 l cd
    cs) (d_OP_linearVariables_dot_uscore_hash_lambda7_dot_uscore_hash_lambda8 r
    cd cs)
  FlatCurry.Curry_Types.Choices_C_BranchExpr d i xs -> narrows cs d i (\z ->
    d_OP_linearVariables_dot_uscore_hash_lambda7_dot_uscore_hash_lambda8 z cd
    cs) xs
  FlatCurry.Curry_Types.Guard_C_BranchExpr d c e -> guardCons d c ((\x ->
    d_OP_linearVariables_dot_uscore_hash_lambda7_dot_uscore_hash_lambda8 e cd
    x) $! addCs c cs)
  FlatCurry.Curry_Types.Fail_C_BranchExpr d info -> failCons d (traceFail
    "Analysis.RightLinearity.linearVariables._#lambda7._#lambda8" [show x1]
    info)
  _ -> failCons cd (consFail
    "Analysis.RightLinearity.linearVariables._#lambda7._#lambda8" (showCons x1))

d_OP_linearVariables_dot_uscore_hash_lambda7_dot_uscore_hash_lambda9 :: Curry_Prelude.OP_List
  FlatCurry.Curry_Types.C_BranchExpr -> Curry_Prelude.OP_List
  Curry_Prelude.C_Int -> Curry_Prelude.OP_List (Curry_Prelude.OP_List
  Curry_Prelude.C_Int) -> Cover -> ConstStore -> Curry_Prelude.C_Maybe
  (Curry_Prelude.OP_List Curry_Prelude.C_Int)
d_OP_linearVariables_dot_uscore_hash_lambda7_dot_uscore_hash_lambda9 x1 x2 x3 cd cs =
  let x4 = Curry_Prelude.d_OP_plus_plus (Curry_Prelude.d_C_foldr (acceptCs id
        (Data.Curry_List.d_C_union
        Curry_Prelude.d_OP_uscore_inst_hash_Prelude_dot_Eq_hash_Prelude_dot_Int_hash))
        Curry_Prelude.OP_List (Curry_Prelude.d_C_map
        d_OP_linearVariables_dot_uscore_hash_lambda7_dot_uscore_hash_lambda9_dot_uscore_hash_lambda10
        (Curry_Prelude.d_C_zip x1 x3 cd cs) cd cs) cd cs) x2 cd cs
  in d_C__case_0 x4
  (Curry_Prelude.d_OP_uscore_impl_hash_eq_eq_hash_Prelude_dot_Eq_hash_lbracket_rbracket_hash_0_hash_hash
  Curry_Prelude.d_OP_uscore_inst_hash_Prelude_dot_Eq_hash_Prelude_dot_Int_hash
  (Data.Curry_List.d_C_nub
  Curry_Prelude.d_OP_uscore_inst_hash_Prelude_dot_Eq_hash_Prelude_dot_Int_hash
  x4 cd cs) x4 cd cs) cd cs

d_OP_linearVariables_dot_uscore_hash_lambda7_dot_uscore_hash_lambda9_dot_uscore_hash_lambda10 :: Curry_Prelude.OP_Tuple2
  FlatCurry.Curry_Types.C_BranchExpr (Curry_Prelude.OP_List Curry_Prelude.C_Int)
  -> Cover -> ConstStore -> Curry_Prelude.OP_List Curry_Prelude.C_Int
d_OP_linearVariables_dot_uscore_hash_lambda7_dot_uscore_hash_lambda9_dot_uscore_hash_lambda10 x1 cd cs =
  case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> Data.Curry_List.d_OP_backslash_backslash
    Curry_Prelude.d_OP_uscore_inst_hash_Prelude_dot_Eq_hash_Prelude_dot_Int_hash
    x3 (d_OP_linearVariables_dot_patternVars_dot_52 x2 cd cs) cd cs
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (d_OP_linearVariables_dot_uscore_hash_lambda7_dot_uscore_hash_lambda9_dot_uscore_hash_lambda10
    l cd cs)
    (d_OP_linearVariables_dot_uscore_hash_lambda7_dot_uscore_hash_lambda9_dot_uscore_hash_lambda10
    r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    d_OP_linearVariables_dot_uscore_hash_lambda7_dot_uscore_hash_lambda9_dot_uscore_hash_lambda10
    z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c ((\x ->
    d_OP_linearVariables_dot_uscore_hash_lambda7_dot_uscore_hash_lambda9_dot_uscore_hash_lambda10
    e cd x) $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "Analysis.RightLinearity.linearVariables._#lambda7._#lambda9._#lambda10"
    [show x1] info)
  _ -> failCons cd (consFail
    "Analysis.RightLinearity.linearVariables._#lambda7._#lambda9._#lambda10"
    (showCons x1))

d_C__case_6 :: Analysis.Curry_Types.C_AOutFormat -> Cover -> ConstStore
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C__case_6 x1 cd cs = case x1 of
  Analysis.Curry_Types.C_AText -> Curry_Prelude.toCurryString
    "not defined by right-linear rules"
  Analysis.Curry_Types.C_ANote -> Curry_Prelude.OP_List
  Analysis.Curry_Types.Choice_C_AOutFormat d i l r -> narrow d i (d_C__case_6 l
    cd cs) (d_C__case_6 r cd cs)
  Analysis.Curry_Types.Choices_C_AOutFormat d i xs -> narrows cs d i (\z ->
    d_C__case_6 z cd cs) xs
  Analysis.Curry_Types.Guard_C_AOutFormat d c e -> guardCons d c ((\x ->
    d_C__case_6 e cd x) $! addCs c cs)
  Analysis.Curry_Types.Fail_C_AOutFormat d info -> failCons d (traceFail
    "Analysis.RightLinearity._case_6" [show x1] info)
  _ -> failCons cd (consFail "Analysis.RightLinearity._case_6" (showCons x1))

d_C__case_5 :: Curry_Prelude.OP_List FlatCurry.Curry_Types.C_Expr
  -> Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List Curry_Prelude.C_Char)
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Curry_Prelude.C_Bool -> Cover
  -> ConstStore -> Curry_Prelude.C_Maybe (Curry_Prelude.OP_List
  Curry_Prelude.C_Int)
d_C__case_5 x6 x5 x7 cd cs = case x7 of
  Curry_Prelude.C_True -> d_C_linearVariables (FlatCurry.Curry_Types.C_Or
    (Curry_Prelude.d_C_head x6 cd cs) (Curry_Prelude.d_C_head
    (Curry_Prelude.d_C_tail x6 cd cs) cd cs)) cd cs
  Curry_Prelude.C_False -> d_C__case_4 x6 (Curry_Prelude.d_C_otherwise cd cs) cd
    cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_5 x6 x5 l cd cs)
    (d_C__case_5 x6 x5 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_5 x6 x5
    z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c ((\x -> d_C__case_5 x6 x5 e
    cd x) $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "Analysis.RightLinearity._case_5" [show x6, show x5, show x7] info)
  _ -> failCons cd (consFail "Analysis.RightLinearity._case_5" (showCons x7))

d_C__case_4 :: Curry_Prelude.OP_List FlatCurry.Curry_Types.C_Expr
  -> Curry_Prelude.C_Bool -> Cover -> ConstStore -> Curry_Prelude.C_Maybe
  (Curry_Prelude.OP_List Curry_Prelude.C_Int)
d_C__case_4 x6 x7 cd cs = case x7 of
  Curry_Prelude.C_True -> Curry_Prelude.d_OP_uscore_impl_hash_gt_gt_eq_hash_Prelude_dot_Monad_hash_Prelude_dot_Maybe_hash
    (Curry_Prelude.d_C_apply (Curry_Prelude.d_C_mapM
    Curry_Prelude.d_OP_uscore_inst_hash_Prelude_dot_Monad_hash_Prelude_dot_Maybe_hash
    d_C_linearVariables cd cs) x6 cd cs)
    d_OP_linearVariables_dot_uscore_hash_lambda1 cd cs
  Curry_Prelude.C_False -> Curry_Prelude.d_C_failed cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_4 x6 l cd cs)
    (d_C__case_4 x6 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_4 x6 z
    cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c ((\x -> d_C__case_4 x6 e cd
    x) $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "Analysis.RightLinearity._case_4" [show x6, show x7] info)
  _ -> failCons cd (consFail "Analysis.RightLinearity._case_4" (showCons x7))

d_C__case_3 :: Curry_Prelude.OP_List Curry_Prelude.C_Int -> Curry_Prelude.C_Bool
  -> Cover -> ConstStore -> Curry_Prelude.C_Maybe (Curry_Prelude.OP_List
  Curry_Prelude.C_Int)
d_C__case_3 x2 x3 cd cs = case x3 of
  Curry_Prelude.C_True -> Curry_Prelude.C_Just x2
  Curry_Prelude.C_False -> Curry_Prelude.C_Nothing
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_3 x2 l cd cs)
    (d_C__case_3 x2 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_3 x2 z
    cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c ((\x -> d_C__case_3 x2 e cd
    x) $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "Analysis.RightLinearity._case_3" [show x2, show x3] info)
  _ -> failCons cd (consFail "Analysis.RightLinearity._case_3" (showCons x3))

d_C__case_2 :: Curry_Prelude.OP_List Curry_Prelude.C_Int
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 Curry_Prelude.C_Int
  FlatCurry.Curry_Types.C_Expr) -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_Prelude.C_Maybe (Curry_Prelude.OP_List Curry_Prelude.C_Int)
d_C__case_2 x4 x2 x5 cd cs = case x5 of
  Curry_Prelude.C_True -> Curry_Prelude.C_Just
    (Data.Curry_List.d_OP_backslash_backslash
    Curry_Prelude.d_OP_uscore_inst_hash_Prelude_dot_Eq_hash_Prelude_dot_Int_hash
    x4 (Curry_Prelude.d_C_map Curry_Prelude.d_C_fst x2 cd cs) cd cs)
  Curry_Prelude.C_False -> Curry_Prelude.C_Nothing
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_2 x4 x2 l cd cs)
    (d_C__case_2 x4 x2 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_2 x4 x2
    z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c ((\x -> d_C__case_2 x4 x2 e
    cd x) $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "Analysis.RightLinearity._case_2" [show x4, show x2, show x5] info)
  _ -> failCons cd (consFail "Analysis.RightLinearity._case_2" (showCons x5))

d_C__case_1 :: FlatCurry.Curry_Types.C_Pattern -> Cover -> ConstStore
  -> Curry_Prelude.OP_List Curry_Prelude.C_Int
d_C__case_1 x2 cd cs = case x2 of
  FlatCurry.Curry_Types.C_Pattern x4 x5 -> x5
  FlatCurry.Curry_Types.C_LPattern x6 -> Curry_Prelude.OP_List
  FlatCurry.Curry_Types.Choice_C_Pattern d i l r -> narrow d i (d_C__case_1 l cd
    cs) (d_C__case_1 r cd cs)
  FlatCurry.Curry_Types.Choices_C_Pattern d i xs -> narrows cs d i (\z ->
    d_C__case_1 z cd cs) xs
  FlatCurry.Curry_Types.Guard_C_Pattern d c e -> guardCons d c ((\x ->
    d_C__case_1 e cd x) $! addCs c cs)
  FlatCurry.Curry_Types.Fail_C_Pattern d info -> failCons d (traceFail
    "Analysis.RightLinearity._case_1" [show x2] info)
  _ -> failCons cd (consFail "Analysis.RightLinearity._case_1" (showCons x2))

d_C__case_0 :: Curry_Prelude.OP_List Curry_Prelude.C_Int -> Curry_Prelude.C_Bool
  -> Cover -> ConstStore -> Curry_Prelude.C_Maybe (Curry_Prelude.OP_List
  Curry_Prelude.C_Int)
d_C__case_0 x4 x5 cd cs = case x5 of
  Curry_Prelude.C_True -> Curry_Prelude.C_Just x4
  Curry_Prelude.C_False -> Curry_Prelude.C_Nothing
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_0 x4 l cd cs)
    (d_C__case_0 x4 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_0 x4 z
    cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c ((\x -> d_C__case_0 x4 e cd
    x) $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "Analysis.RightLinearity._case_0" [show x4, show x5] info)
  _ -> failCons cd (consFail "Analysis.RightLinearity._case_0" (showCons x5))

