{-# LANGUAGE MagicHash #-}
{-# LANGUAGE ScopedTypeVariables #-}
{-# LANGUAGE QuantifiedConstraints #-}
{-# LANGUAGE RankNTypes #-}
{-# LANGUAGE PolyKinds #-}
{-# LANGUAGE MultiParamTypeClasses #-}
{-# LANGUAGE FlexibleInstances #-}
{-# LANGUAGE CPP #-}
{-# OPTIONS_GHC -fno-warn-overlapping-patterns #-}
{-# OPTIONS_GHC -fno-warn-missing-methods #-}
#if __GLASGOW_HASKELL__ >= 800
{-# OPTIONS_GHC -fno-warn-redundant-constraints #-}
#else
{-# OPTIONS_GHC -fno-warn-duplicate-constraints #-}
#endif

module Contract.Curry_Names
  ( d_C_isSpecName
  , d_C_toSpecName
  , d_C_toSpecQName
  , d_C_fromSpecName
  , d_C_isPreCondName
  , d_C_toPreCondName
  , d_C_toPreCondQName
  , d_C_fromPreCondName
  , d_C_isPostCondName
  , d_C_toPostCondName
  , d_C_toPostCondQName
  , d_C_fromPostCondName
  , d_C_isNonFailName
  , d_C_toNonFailName
  , d_C_toNonFailQName
  , d_C_fromNonFailName
  , d_C_decodeContractQName
  , d_C_decodeContractName
  , d_C_encodeContractQName
  , d_C_encodeContractName )
  where

import Basics
import qualified Data.Curry_List
import qualified Curry_Numeric
import qualified Curry_Prelude


d_C_isSpecName :: Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover
  -> ConstStore -> Curry_Prelude.C_Bool
d_C_isSpecName x1 cd cs = Data.Curry_List.d_C_isSuffixOf
  Curry_Prelude.d_OP_uscore_inst_hash_Prelude_dot_Eq_hash_Prelude_dot_Char_hash
  (Curry_Prelude.toCurryString "'spec") x1 cd cs

d_C_toSpecName :: Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char
d_C_toSpecName cd cs = Curry_Prelude.d_C_flip (acceptCs id
  Curry_Prelude.d_OP_plus_plus) (Curry_Prelude.toCurryString "'spec")

d_C_toSpecQName :: Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Cover
  -> ConstStore -> Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) (Curry_Prelude.OP_List Curry_Prelude.C_Char)
d_C_toSpecQName x1 cd cs = case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> Curry_Prelude.OP_Tuple2 x2
    (Curry_Prelude.d_C_apply (d_C_toSpecName cd cs) x3 cd cs)
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i (d_C_toSpecQName l cd cs)
    (d_C_toSpecQName r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    d_C_toSpecQName z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c ((\x -> d_C_toSpecQName e
    cd x) $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "Contract.Names.toSpecQName" [show x1] info)
  _ -> failCons cd (consFail "Contract.Names.toSpecQName" (showCons x1))

d_C_fromSpecName :: Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover
  -> ConstStore -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C_fromSpecName x1 cd cs = let x2 = Curry_Prelude.d_C_apply
                                  (Curry_Prelude.d_C_reverse cd cs) x1 cd cs
  in Curry_Prelude.d_C_apply (Curry_Prelude.d_C_reverse cd cs)
  (Curry_Prelude.d_C_drop (d_C__case_13 x2
  (Curry_Prelude.d_OP_uscore_impl_hash_eq_eq_hash_Prelude_dot_Eq_hash_lbracket_rbracket_hash_0_hash_hash
  Curry_Prelude.d_OP_uscore_inst_hash_Prelude_dot_Eq_hash_Prelude_dot_Char_hash
  (Curry_Prelude.d_C_take (Curry_Prelude.C_Int (5)) x2 cd cs)
  (Curry_Prelude.toCurryString "ceps'") cd cs) cd cs) x2 cd cs) cd cs

d_C_isPreCondName :: Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover
  -> ConstStore -> Curry_Prelude.C_Bool
d_C_isPreCondName x1 cd cs = Data.Curry_List.d_C_isSuffixOf
  Curry_Prelude.d_OP_uscore_inst_hash_Prelude_dot_Eq_hash_Prelude_dot_Char_hash
  (Curry_Prelude.toCurryString "'pre") x1 cd cs

d_C_toPreCondName :: Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char
d_C_toPreCondName cd cs = Curry_Prelude.d_C_flip (acceptCs id
  Curry_Prelude.d_OP_plus_plus) (Curry_Prelude.toCurryString "'pre")

d_C_toPreCondQName :: Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Cover
  -> ConstStore -> Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) (Curry_Prelude.OP_List Curry_Prelude.C_Char)
d_C_toPreCondQName x1 cd cs = case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> Curry_Prelude.OP_Tuple2 x2
    (Curry_Prelude.d_C_apply (d_C_toPreCondName cd cs) x3 cd cs)
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i (d_C_toPreCondQName l cd
    cs) (d_C_toPreCondQName r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    d_C_toPreCondQName z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c ((\x ->
    d_C_toPreCondQName e cd x) $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "Contract.Names.toPreCondQName" [show x1] info)
  _ -> failCons cd (consFail "Contract.Names.toPreCondQName" (showCons x1))

d_C_fromPreCondName :: Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover
  -> ConstStore -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C_fromPreCondName x1 cd cs = let x2 = Curry_Prelude.d_C_apply
                                     (Curry_Prelude.d_C_reverse cd cs) x1 cd cs
  in Curry_Prelude.d_C_apply (Curry_Prelude.d_C_reverse cd cs)
  (Curry_Prelude.d_C_drop (d_C__case_12 x2
  (Curry_Prelude.d_OP_uscore_impl_hash_eq_eq_hash_Prelude_dot_Eq_hash_lbracket_rbracket_hash_0_hash_hash
  Curry_Prelude.d_OP_uscore_inst_hash_Prelude_dot_Eq_hash_Prelude_dot_Char_hash
  (Curry_Prelude.d_C_take (Curry_Prelude.C_Int (4)) x2 cd cs)
  (Curry_Prelude.toCurryString "erp'") cd cs) cd cs) x2 cd cs) cd cs

d_C_isPostCondName :: Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover
  -> ConstStore -> Curry_Prelude.C_Bool
d_C_isPostCondName x1 cd cs = Data.Curry_List.d_C_isSuffixOf
  Curry_Prelude.d_OP_uscore_inst_hash_Prelude_dot_Eq_hash_Prelude_dot_Char_hash
  (Curry_Prelude.toCurryString "'post") x1 cd cs

d_C_toPostCondName :: Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char
d_C_toPostCondName cd cs = Curry_Prelude.d_C_flip (acceptCs id
  Curry_Prelude.d_OP_plus_plus) (Curry_Prelude.toCurryString "'post")

d_C_toPostCondQName :: Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Cover
  -> ConstStore -> Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) (Curry_Prelude.OP_List Curry_Prelude.C_Char)
d_C_toPostCondQName x1 cd cs = case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> Curry_Prelude.OP_Tuple2 x2
    (Curry_Prelude.d_C_apply (d_C_toPostCondName cd cs) x3 cd cs)
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i (d_C_toPostCondQName l cd
    cs) (d_C_toPostCondQName r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    d_C_toPostCondQName z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c ((\x ->
    d_C_toPostCondQName e cd x) $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "Contract.Names.toPostCondQName" [show x1] info)
  _ -> failCons cd (consFail "Contract.Names.toPostCondQName" (showCons x1))

d_C_fromPostCondName :: Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover
  -> ConstStore -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C_fromPostCondName x1 cd cs = let x2 = Curry_Prelude.d_C_apply
                                      (Curry_Prelude.d_C_reverse cd cs) x1 cd cs
  in Curry_Prelude.d_C_apply (Curry_Prelude.d_C_reverse cd cs)
  (Curry_Prelude.d_C_drop (d_C__case_11 x2
  (Curry_Prelude.d_OP_uscore_impl_hash_eq_eq_hash_Prelude_dot_Eq_hash_lbracket_rbracket_hash_0_hash_hash
  Curry_Prelude.d_OP_uscore_inst_hash_Prelude_dot_Eq_hash_Prelude_dot_Char_hash
  (Curry_Prelude.d_C_take (Curry_Prelude.C_Int (5)) x2 cd cs)
  (Curry_Prelude.toCurryString "tsop'") cd cs) cd cs) x2 cd cs) cd cs

d_C_isNonFailName :: Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover
  -> ConstStore -> Curry_Prelude.C_Bool
d_C_isNonFailName x1 cd cs = Data.Curry_List.d_C_isSuffixOf
  Curry_Prelude.d_OP_uscore_inst_hash_Prelude_dot_Eq_hash_Prelude_dot_Char_hash
  (Curry_Prelude.toCurryString "'nonfail") x1 cd cs

d_C_toNonFailName :: Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char
d_C_toNonFailName cd cs = Curry_Prelude.d_C_flip (acceptCs id
  Curry_Prelude.d_OP_plus_plus) (Curry_Prelude.toCurryString "'nonfail")

d_C_toNonFailQName :: Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Cover
  -> ConstStore -> Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) (Curry_Prelude.OP_List Curry_Prelude.C_Char)
d_C_toNonFailQName x1 cd cs = case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> Curry_Prelude.OP_Tuple2 x2
    (Curry_Prelude.d_C_apply (d_C_toNonFailName cd cs) x3 cd cs)
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i (d_C_toNonFailQName l cd
    cs) (d_C_toNonFailQName r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    d_C_toNonFailQName z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c ((\x ->
    d_C_toNonFailQName e cd x) $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "Contract.Names.toNonFailQName" [show x1] info)
  _ -> failCons cd (consFail "Contract.Names.toNonFailQName" (showCons x1))

d_C_fromNonFailName :: Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover
  -> ConstStore -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C_fromNonFailName x1 cd cs = let x2 = Curry_Prelude.d_C_apply
                                     (Curry_Prelude.d_C_reverse cd cs) x1 cd cs
  in Curry_Prelude.d_C_apply (Curry_Prelude.d_C_reverse cd cs)
  (Curry_Prelude.d_C_drop (d_C__case_10 x2
  (Curry_Prelude.d_OP_uscore_impl_hash_eq_eq_hash_Prelude_dot_Eq_hash_lbracket_rbracket_hash_0_hash_hash
  Curry_Prelude.d_OP_uscore_inst_hash_Prelude_dot_Eq_hash_Prelude_dot_Char_hash
  (Curry_Prelude.d_C_take (Curry_Prelude.C_Int (8)) x2 cd cs)
  (Curry_Prelude.toCurryString "liafnon'") cd cs) cd cs) x2 cd cs) cd cs

d_C_decodeContractQName :: Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Cover
  -> ConstStore -> Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) (Curry_Prelude.OP_List Curry_Prelude.C_Char)
d_C_decodeContractQName x1 cd cs = case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> Curry_Prelude.OP_Tuple2 x2
    (d_C_decodeContractName x3 cd cs)
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i (d_C_decodeContractQName
    l cd cs) (d_C_decodeContractQName r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    d_C_decodeContractQName z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c ((\x ->
    d_C_decodeContractQName e cd x) $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "Contract.Names.decodeContractQName" [show x1] info)
  _ -> failCons cd (consFail "Contract.Names.decodeContractQName" (showCons x1))

d_C_decodeContractName :: Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover
  -> ConstStore -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C_decodeContractName x1 cd cs = let x2 = Curry_Prelude.d_C_apply
                                        (Curry_Prelude.d_C_break
                                        (Curry_Prelude.d_C_flip (acceptCs id
                                        Curry_Prelude.d_OP_uscore_impl_hash_eq_eq_hash_Prelude_dot_Eq_hash_Prelude_dot_Char_hash)
                                        (Curry_Prelude.C_Char '\''#)) cd cs) x1
                                        cd cs
                                      x3 = d_OP_decodeContractName_dot_uscore_hash_selFP2_hash_fnop
                                        x2 cd cs
                                      x4 = d_OP_decodeContractName_dot_uscore_hash_selFP3_hash_fntail
                                        x2 cd cs
  in d_C__case_9 x4 x1 x3 (Curry_Prelude.d_OP_amp_amp
  (Data.Curry_List.d_C_isPrefixOf
  Curry_Prelude.d_OP_uscore_inst_hash_Prelude_dot_Eq_hash_Prelude_dot_Char_hash
  (Curry_Prelude.toCurryString "op_x") x1 cd cs) (Curry_Prelude.d_C_not
  (Curry_Prelude.d_C_null x4 cd cs) cd cs) cd cs) cd cs

d_OP_decodeContractName_dot_uscore_hash_selFP2_hash_fnop :: Curry_Prelude.OP_Tuple2
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) -> Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char
d_OP_decodeContractName_dot_uscore_hash_selFP2_hash_fnop x1 cd cs = case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> x2
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (d_OP_decodeContractName_dot_uscore_hash_selFP2_hash_fnop l cd cs)
    (d_OP_decodeContractName_dot_uscore_hash_selFP2_hash_fnop r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    d_OP_decodeContractName_dot_uscore_hash_selFP2_hash_fnop z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c ((\x ->
    d_OP_decodeContractName_dot_uscore_hash_selFP2_hash_fnop e cd x) $! addCs c
    cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "Contract.Names.decodeContractName._#selFP2#fnop" [show x1] info)
  _ -> failCons cd (consFail "Contract.Names.decodeContractName._#selFP2#fnop"
    (showCons x1))

d_OP_decodeContractName_dot_uscore_hash_selFP3_hash_fntail :: Curry_Prelude.OP_Tuple2
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) -> Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char
d_OP_decodeContractName_dot_uscore_hash_selFP3_hash_fntail x1 cd cs = case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> x3
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (d_OP_decodeContractName_dot_uscore_hash_selFP3_hash_fntail l cd cs)
    (d_OP_decodeContractName_dot_uscore_hash_selFP3_hash_fntail r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    d_OP_decodeContractName_dot_uscore_hash_selFP3_hash_fntail z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c ((\x ->
    d_OP_decodeContractName_dot_uscore_hash_selFP3_hash_fntail e cd x) $! addCs
    c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "Contract.Names.decodeContractName._#selFP3#fntail" [show x1] info)
  _ -> failCons cd (consFail "Contract.Names.decodeContractName._#selFP3#fntail"
    (showCons x1))

d_OP_decodeContractName_dot_fromHex_dot_44 :: Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char
d_OP_decodeContractName_dot_fromHex_dot_44 x1 x2 x3 x4 cd cs = case x4 of
  Curry_Prelude.OP_List -> Curry_Prelude.d_OP_plus_plus (Curry_Prelude.d_C_apply
    (Curry_Prelude.d_C_reverse cd cs) x3 cd cs) x2 cd cs
  Curry_Prelude.OP_Cons x5 x6 -> d_C__case_7 x5 x1 x3 x2 x6 cd cs
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i
    (d_OP_decodeContractName_dot_fromHex_dot_44 x1 x2 x3 l cd cs)
    (d_OP_decodeContractName_dot_fromHex_dot_44 x1 x2 x3 r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z ->
    d_OP_decodeContractName_dot_fromHex_dot_44 x1 x2 x3 z cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c ((\x ->
    d_OP_decodeContractName_dot_fromHex_dot_44 x1 x2 x3 e cd x) $! addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail
    "Contract.Names.decodeContractName.fromHex.44" [show x1, show x2, show x3
    , show x4] info)
  _ -> failCons cd (consFail "Contract.Names.decodeContractName.fromHex.44"
    (showCons x4))

d_C_encodeContractQName :: Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Cover
  -> ConstStore -> Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) (Curry_Prelude.OP_List Curry_Prelude.C_Char)
d_C_encodeContractQName x1 cd cs = case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> Curry_Prelude.OP_Tuple2 x2
    (d_C_encodeContractName x3 cd cs)
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i (d_C_encodeContractQName
    l cd cs) (d_C_encodeContractQName r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    d_C_encodeContractQName z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c ((\x ->
    d_C_encodeContractQName e cd x) $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "Contract.Names.encodeContractQName" [show x1] info)
  _ -> failCons cd (consFail "Contract.Names.encodeContractQName" (showCons x1))

d_C_encodeContractName :: Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover
  -> ConstStore -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C_encodeContractName x1 cd cs = let x2 = Curry_Prelude.d_C_apply
                                        (Curry_Prelude.d_C_break
                                        (Curry_Prelude.d_C_flip (acceptCs id
                                        Curry_Prelude.d_OP_uscore_impl_hash_eq_eq_hash_Prelude_dot_Eq_hash_Prelude_dot_Char_hash)
                                        (Curry_Prelude.C_Char '\''#)) cd cs)
                                        (Curry_Prelude.d_C_apply
                                        (Curry_Prelude.d_C_reverse cd cs) x1 cd
                                        cs) cd cs
                                      x3 = d_OP_encodeContractName_dot_uscore_hash_selFP5_hash_rsuf
                                        x2 cd cs
                                      x4 = d_OP_encodeContractName_dot_uscore_hash_selFP6_hash_rop
                                        x2 cd cs
  in d_C__case_2 x4 x3 x1 (Curry_Prelude.d_OP_bar_bar (Curry_Prelude.d_C_null x4
  cd cs) (Curry_Prelude.d_OP_bar_bar (Curry_Prelude.d_C_null x3 cd cs)
  (Curry_Prelude.d_C_apply (Curry_Prelude.d_C_all
  d_OP_encodeContractName_dot_uscore_hash_lambda2 cd cs) x4 cd cs) cd cs) cd cs)
  cd cs

d_OP_encodeContractName_dot_uscore_hash_selFP5_hash_rsuf :: Curry_Prelude.OP_Tuple2
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) -> Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char
d_OP_encodeContractName_dot_uscore_hash_selFP5_hash_rsuf x1 cd cs = case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> x2
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (d_OP_encodeContractName_dot_uscore_hash_selFP5_hash_rsuf l cd cs)
    (d_OP_encodeContractName_dot_uscore_hash_selFP5_hash_rsuf r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    d_OP_encodeContractName_dot_uscore_hash_selFP5_hash_rsuf z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c ((\x ->
    d_OP_encodeContractName_dot_uscore_hash_selFP5_hash_rsuf e cd x) $! addCs c
    cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "Contract.Names.encodeContractName._#selFP5#rsuf" [show x1] info)
  _ -> failCons cd (consFail "Contract.Names.encodeContractName._#selFP5#rsuf"
    (showCons x1))

d_OP_encodeContractName_dot_uscore_hash_selFP6_hash_rop :: Curry_Prelude.OP_Tuple2
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) -> Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char
d_OP_encodeContractName_dot_uscore_hash_selFP6_hash_rop x1 cd cs = case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> x3
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (d_OP_encodeContractName_dot_uscore_hash_selFP6_hash_rop l cd cs)
    (d_OP_encodeContractName_dot_uscore_hash_selFP6_hash_rop r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    d_OP_encodeContractName_dot_uscore_hash_selFP6_hash_rop z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c ((\x ->
    d_OP_encodeContractName_dot_uscore_hash_selFP6_hash_rop e cd x) $! addCs c
    cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "Contract.Names.encodeContractName._#selFP6#rop" [show x1] info)
  _ -> failCons cd (consFail "Contract.Names.encodeContractName._#selFP6#rop"
    (showCons x1))

d_OP_encodeContractName_dot_toHexDigit_dot_62 :: Curry_Prelude.C_Int -> Cover
  -> ConstStore -> Curry_Prelude.C_Char
d_OP_encodeContractName_dot_toHexDigit_dot_62 x1 cd cs = d_C__case_0 x1
  (Curry_Prelude.d_C_apply (Curry_Prelude.d_C_apply
  (Curry_Prelude.d_OP_uscore_impl_hash_lt_hash_Prelude_dot_Ord_hash_Prelude_dot_Int_hash
  cd cs) x1 cd cs) (Curry_Prelude.C_Int (10)) cd cs) cd cs

d_OP_encodeContractName_dot_toHex_dot_62 :: Curry_Prelude.C_Char -> Cover
  -> ConstStore -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_OP_encodeContractName_dot_toHex_dot_62 x1 cd cs =
  let x2 = Curry_Prelude.d_C_ord x1 cd cs
  in Curry_Prelude.OP_Cons (d_OP_encodeContractName_dot_toHexDigit_dot_62
  (Curry_Prelude.d_C_apply (Curry_Prelude.d_C_apply
  (Curry_Prelude.d_OP_uscore_impl_hash_div_hash_Prelude_dot_Integral_hash_Prelude_dot_Int_hash
  cd cs) x2 cd cs) (Curry_Prelude.C_Int (16)) cd cs) cd cs)
  (Curry_Prelude.OP_Cons (d_OP_encodeContractName_dot_toHexDigit_dot_62
  (Curry_Prelude.d_C_apply (Curry_Prelude.d_C_apply
  (Curry_Prelude.d_OP_uscore_impl_hash_mod_hash_Prelude_dot_Integral_hash_Prelude_dot_Int_hash
  cd cs) x2 cd cs) (Curry_Prelude.C_Int (16)) cd cs) cd cs)
  Curry_Prelude.OP_List)

d_OP_encodeContractName_dot_uscore_hash_lambda2 :: Curry_Prelude.C_Char -> Cover
  -> ConstStore -> Curry_Prelude.C_Bool
d_OP_encodeContractName_dot_uscore_hash_lambda2 x1 cd cs =
  Curry_Prelude.d_OP_bar_bar (Curry_Prelude.d_C_isAlphaNum x1 cd cs)
  (Curry_Prelude.d_OP_bar_bar
  (Curry_Prelude.d_OP_uscore_impl_hash_eq_eq_hash_Prelude_dot_Eq_hash_Prelude_dot_Char_hash
  x1 (Curry_Prelude.C_Char '\''#) cd cs)
  (Curry_Prelude.d_OP_uscore_impl_hash_eq_eq_hash_Prelude_dot_Eq_hash_Prelude_dot_Char_hash
  x1 (Curry_Prelude.C_Char '_'#) cd cs) cd cs) cd cs

d_C__case_13 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.C_Bool -> Cover -> ConstStore -> Curry_Prelude.C_Int
d_C__case_13 x2 x3 cd cs = case x3 of
  Curry_Prelude.C_True -> Curry_Prelude.C_Int (5)
  Curry_Prelude.C_False -> Curry_Prelude.C_Int (0)
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_13 x2 l cd cs)
    (d_C__case_13 x2 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_13 x2 z
    cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c ((\x -> d_C__case_13 x2 e cd
    x) $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "Contract.Names._case_13" [show x2, show x3] info)
  _ -> failCons cd (consFail "Contract.Names._case_13" (showCons x3))

d_C__case_12 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.C_Bool -> Cover -> ConstStore -> Curry_Prelude.C_Int
d_C__case_12 x2 x3 cd cs = case x3 of
  Curry_Prelude.C_True -> Curry_Prelude.C_Int (4)
  Curry_Prelude.C_False -> Curry_Prelude.C_Int (0)
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_12 x2 l cd cs)
    (d_C__case_12 x2 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_12 x2 z
    cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c ((\x -> d_C__case_12 x2 e cd
    x) $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "Contract.Names._case_12" [show x2, show x3] info)
  _ -> failCons cd (consFail "Contract.Names._case_12" (showCons x3))

d_C__case_11 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.C_Bool -> Cover -> ConstStore -> Curry_Prelude.C_Int
d_C__case_11 x2 x3 cd cs = case x3 of
  Curry_Prelude.C_True -> Curry_Prelude.C_Int (5)
  Curry_Prelude.C_False -> Curry_Prelude.C_Int (0)
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_11 x2 l cd cs)
    (d_C__case_11 x2 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_11 x2 z
    cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c ((\x -> d_C__case_11 x2 e cd
    x) $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "Contract.Names._case_11" [show x2, show x3] info)
  _ -> failCons cd (consFail "Contract.Names._case_11" (showCons x3))

d_C__case_10 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.C_Bool -> Cover -> ConstStore -> Curry_Prelude.C_Int
d_C__case_10 x2 x3 cd cs = case x3 of
  Curry_Prelude.C_True -> Curry_Prelude.C_Int (8)
  Curry_Prelude.C_False -> Curry_Prelude.C_Int (0)
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_10 x2 l cd cs)
    (d_C__case_10 x2 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_10 x2 z
    cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c ((\x -> d_C__case_10 x2 e cd
    x) $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "Contract.Names._case_10" [show x2, show x3] info)
  _ -> failCons cd (consFail "Contract.Names._case_10" (showCons x3))

d_C__case_9 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C__case_9 x4 x1 x3 x5 cd cs = case x5 of
  Curry_Prelude.C_True -> d_OP_decodeContractName_dot_fromHex_dot_44 x1 x4
    Curry_Prelude.OP_List (Curry_Prelude.d_C_drop (Curry_Prelude.C_Int (4)) x3
    cd cs) cd cs
  Curry_Prelude.C_False -> d_C__case_8 x1 (Curry_Prelude.d_C_otherwise cd cs) cd
    cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_9 x4 x1 x3 l cd
    cs) (d_C__case_9 x4 x1 x3 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_9 x4 x1
    x3 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c ((\x -> d_C__case_9 x4 x1 x3
    e cd x) $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "Contract.Names._case_9" [show x4, show x1, show x3, show x5] info)
  _ -> failCons cd (consFail "Contract.Names._case_9" (showCons x5))

d_C__case_8 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.C_Bool -> Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char
d_C__case_8 x1 x2 cd cs = case x2 of
  Curry_Prelude.C_True -> x1
  Curry_Prelude.C_False -> Curry_Prelude.d_C_failed cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_8 x1 l cd cs)
    (d_C__case_8 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_8 x1 z
    cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c ((\x -> d_C__case_8 x1 e cd
    x) $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "Contract.Names._case_8" [show x1, show x2] info)
  _ -> failCons cd (consFail "Contract.Names._case_8" (showCons x2))

d_C__case_7 :: Curry_Prelude.C_Char -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char
d_C__case_7 x5 x1 x3 x2 x6 cd cs = case x6 of
  Curry_Prelude.OP_List -> x1
  Curry_Prelude.OP_Cons x7 x8 -> d_C__case_6 x7 x5 x1 x8 x3 x2
    (Curry_Numeric.d_C_readHex (Curry_Prelude.OP_Cons x5 (Curry_Prelude.OP_Cons
    x7 Curry_Prelude.OP_List)) cd cs) cd cs
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (d_C__case_7 x5 x1 x3 x2 l
    cd cs) (d_C__case_7 x5 x1 x3 x2 r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z -> d_C__case_7 x5
    x1 x3 x2 z cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c ((\x -> d_C__case_7 x5 x1
    x3 x2 e cd x) $! addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail
    "Contract.Names._case_7" [show x5, show x1, show x3, show x2, show x6] info)
  _ -> failCons cd (consFail "Contract.Names._case_7" (showCons x6))

d_C__case_6 :: Curry_Prelude.C_Char -> Curry_Prelude.C_Char
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_Tuple2 Curry_Prelude.C_Int (Curry_Prelude.OP_List
  Curry_Prelude.C_Char)) -> Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char
d_C__case_6 x7 x5 x1 x8 x3 x2 x11 cd cs = case x11 of
  Curry_Prelude.OP_Cons x9 x10 -> d_C__case_5 x1 x10 x8 x3 x2 x9 cd cs
  Curry_Prelude.OP_List -> x1
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (d_C__case_6 x7 x5 x1 x8 x3
    x2 l cd cs) (d_C__case_6 x7 x5 x1 x8 x3 x2 r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z -> d_C__case_6 x7
    x5 x1 x8 x3 x2 z cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c ((\x -> d_C__case_6 x7 x5
    x1 x8 x3 x2 e cd x) $! addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail
    "Contract.Names._case_6" [show x7, show x5, show x1, show x8, show x3, show
    x2, show x11] info)
  _ -> failCons cd (consFail "Contract.Names._case_6" (showCons x11))

d_C__case_5 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 Curry_Prelude.C_Int
  (Curry_Prelude.OP_List Curry_Prelude.C_Char)) -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Curry_Prelude.OP_Tuple2
  Curry_Prelude.C_Int (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Cover
  -> ConstStore -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C__case_5 x1 x10 x8 x3 x2 x9 cd cs = case x9 of
  Curry_Prelude.OP_Tuple2 x11 x12 -> d_C__case_4 x1 x10 x8 x3 x11 x2 x12 cd cs
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i (d_C__case_5 x1 x10 x8 x3
    x2 l cd cs) (d_C__case_5 x1 x10 x8 x3 x2 r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z -> d_C__case_5 x1
    x10 x8 x3 x2 z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c ((\x -> d_C__case_5 x1
    x10 x8 x3 x2 e cd x) $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "Contract.Names._case_5" [show x1, show x10, show x8, show x3, show x2, show
    x9] info)
  _ -> failCons cd (consFail "Contract.Names._case_5" (showCons x9))

d_C__case_4 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 Curry_Prelude.C_Int
  (Curry_Prelude.OP_List Curry_Prelude.C_Char)) -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.C_Int -> Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover -> ConstStore
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C__case_4 x1 x10 x8 x3 x11 x2 x12 cd cs = case x12 of
  Curry_Prelude.OP_List -> d_C__case_3 x1 x8 x3 x11 x2 x10 cd cs
  Curry_Prelude.OP_Cons x15 x16 -> x1
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (d_C__case_4 x1 x10 x8 x3
    x11 x2 l cd cs) (d_C__case_4 x1 x10 x8 x3 x11 x2 r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z -> d_C__case_4 x1
    x10 x8 x3 x11 x2 z cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c ((\x -> d_C__case_4 x1 x10
    x8 x3 x11 x2 e cd x) $! addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail
    "Contract.Names._case_4" [show x1, show x10, show x8, show x3, show x11
    , show x2, show x12] info)
  _ -> failCons cd (consFail "Contract.Names._case_4" (showCons x12))

d_C__case_3 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.C_Int -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2
  Curry_Prelude.C_Int (Curry_Prelude.OP_List Curry_Prelude.C_Char)) -> Cover
  -> ConstStore -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C__case_3 x1 x8 x3 x11 x2 x10 cd cs = case x10 of
  Curry_Prelude.OP_List -> d_OP_decodeContractName_dot_fromHex_dot_44 x1 x2
    (Curry_Prelude.OP_Cons (Curry_Prelude.d_C_chr x11 cd cs) x3) x8 cd cs
  Curry_Prelude.OP_Cons x13 x14 -> x1
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (d_C__case_3 x1 x8 x3 x11
    x2 l cd cs) (d_C__case_3 x1 x8 x3 x11 x2 r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z -> d_C__case_3 x1
    x8 x3 x11 x2 z cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c ((\x -> d_C__case_3 x1 x8
    x3 x11 x2 e cd x) $! addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail
    "Contract.Names._case_3" [show x1, show x8, show x3, show x11, show x2, show
    x10] info)
  _ -> failCons cd (consFail "Contract.Names._case_3" (showCons x10))

d_C__case_2 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C__case_2 x4 x3 x1 x5 cd cs = case x5 of
  Curry_Prelude.C_True -> x1
  Curry_Prelude.C_False -> d_C__case_1 x3 x4 (Curry_Prelude.d_C_otherwise cd cs)
    cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_2 x4 x3 x1 l cd
    cs) (d_C__case_2 x4 x3 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_2 x4 x3
    x1 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c ((\x -> d_C__case_2 x4 x3 x1
    e cd x) $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "Contract.Names._case_2" [show x4, show x3, show x1, show x5] info)
  _ -> failCons cd (consFail "Contract.Names._case_2" (showCons x5))

d_C__case_1 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Curry_Prelude.C_Bool -> Cover
  -> ConstStore -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C__case_1 x3 x4 x5 cd cs = case x5 of
  Curry_Prelude.C_True -> Curry_Prelude.d_OP_plus_plus
    (Curry_Prelude.toCurryString "op_x") (Curry_Prelude.d_OP_plus_plus
    (Curry_Prelude.d_C_apply (Curry_Prelude.d_C_concatMap
    d_OP_encodeContractName_dot_toHex_dot_62 cd cs) (Curry_Prelude.d_C_apply
    (Curry_Prelude.d_C_reverse cd cs) (Curry_Prelude.d_C_tail x4 cd cs) cd cs)
    cd cs) (Curry_Prelude.OP_Cons (Curry_Prelude.C_Char '\''#)
    (Curry_Prelude.d_C_apply (Curry_Prelude.d_C_reverse cd cs) x3 cd cs)) cd cs)
    cd cs
  Curry_Prelude.C_False -> Curry_Prelude.d_C_failed cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_1 x3 x4 l cd cs)
    (d_C__case_1 x3 x4 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_1 x3 x4
    z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c ((\x -> d_C__case_1 x3 x4 e
    cd x) $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "Contract.Names._case_1" [show x3, show x4, show x5] info)
  _ -> failCons cd (consFail "Contract.Names._case_1" (showCons x5))

d_C__case_0 :: Curry_Prelude.C_Int -> Curry_Prelude.C_Bool -> Cover
  -> ConstStore -> Curry_Prelude.C_Char
d_C__case_0 x1 x2 cd cs = case x2 of
  Curry_Prelude.C_True -> Curry_Prelude.d_C_chr
    (Curry_Prelude.d_OP_uscore_impl_hash_plus_hash_Prelude_dot_Num_hash_Prelude_dot_Int_hash
    (Curry_Prelude.d_C_ord (Curry_Prelude.C_Char '0'#) cd cs) x1 cd cs) cd cs
  Curry_Prelude.C_False -> Curry_Prelude.d_C_chr
    (Curry_Prelude.d_OP_uscore_impl_hash_minus_hash_Prelude_dot_Num_hash_Prelude_dot_Int_hash
    (Curry_Prelude.d_OP_uscore_impl_hash_plus_hash_Prelude_dot_Num_hash_Prelude_dot_Int_hash
    (Curry_Prelude.d_C_ord (Curry_Prelude.C_Char 'A'#) cd cs) x1 cd cs)
    (Curry_Prelude.C_Int (10)) cd cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_0 x1 l cd cs)
    (d_C__case_0 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_0 x1 z
    cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c ((\x -> d_C__case_0 x1 e cd
    x) $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "Contract.Names._case_0" [show x1, show x2] info)
  _ -> failCons cd (consFail "Contract.Names._case_0" (showCons x2))

