{-# LANGUAGE MagicHash #-}
{-# LANGUAGE ScopedTypeVariables #-}
{-# LANGUAGE QuantifiedConstraints #-}
{-# LANGUAGE RankNTypes #-}
{-# LANGUAGE PolyKinds #-}
{-# LANGUAGE MultiParamTypeClasses #-}
{-# LANGUAGE FlexibleInstances #-}
{-# LANGUAGE CPP #-}
{-# OPTIONS_GHC -fno-warn-overlapping-patterns #-}
{-# OPTIONS_GHC -fno-warn-missing-methods #-}
#if __GLASGOW_HASKELL__ >= 800
{-# OPTIONS_GHC -fno-warn-redundant-constraints #-}
#else
{-# OPTIONS_GHC -fno-warn-duplicate-constraints #-}
#endif

module Dimacs.Curry_Build
  ( d_C_va
  , d_C_no
  , d_C_nv
  , d_OP_dot_slash_backslash
  , d_OP_dot_backslash_slash
  , d_C_xor
  , d_C_nnf
  , d_C_cnf
  , d_C_dist
  , d_C_flatten
  , d_C_flattenAnd
  , d_C_flattenOr
  , d_C_nubB
  , d_C_toCNF
  , d_C_filterTauts
  , d_C_isTaut )
  where

import Basics
import qualified Data.Curry_List
import qualified Dimacs.Curry_Types
import qualified Curry_Prelude


d_C_va :: Cover -> ConstStore -> Curry_Prelude.C_Int -> Cover -> ConstStore
  -> Dimacs.Curry_Types.C_Boolean
d_C_va cd cs = acceptCs id Dimacs.Curry_Types.C_Var

d_C_no :: Cover -> ConstStore -> Dimacs.Curry_Types.C_Boolean -> Cover
  -> ConstStore -> Dimacs.Curry_Types.C_Boolean
d_C_no cd cs = acceptCs id Dimacs.Curry_Types.C_Not

d_C_nv :: Cover -> ConstStore -> Curry_Prelude.C_Int -> Cover -> ConstStore
  -> Dimacs.Curry_Types.C_Boolean
d_C_nv cd cs = Curry_Prelude.d_OP_dot (d_C_no cd cs) (d_C_va cd cs) cd cs

d_OP_dot_slash_backslash :: Dimacs.Curry_Types.C_Boolean
  -> Dimacs.Curry_Types.C_Boolean -> Cover -> ConstStore
  -> Dimacs.Curry_Types.C_Boolean
d_OP_dot_slash_backslash x1 x2 cd cs = d_C__case_30 x2 x1
  (Curry_Prelude.OP_Tuple2 x1 x2) cd cs

d_OP_dot_backslash_slash :: Dimacs.Curry_Types.C_Boolean
  -> Dimacs.Curry_Types.C_Boolean -> Cover -> ConstStore
  -> Dimacs.Curry_Types.C_Boolean
d_OP_dot_backslash_slash x1 x2 cd cs = d_C__case_24 x2 x1
  (Curry_Prelude.OP_Tuple2 x1 x2) cd cs

d_C_xor :: Dimacs.Curry_Types.C_Boolean -> Dimacs.Curry_Types.C_Boolean -> Cover
  -> ConstStore -> Dimacs.Curry_Types.C_Boolean
d_C_xor x1 x2 cd cs = d_OP_dot_backslash_slash (d_OP_dot_slash_backslash
  (Curry_Prelude.d_C_apply (d_C_no cd cs) x1 cd cs) x2 cd cs)
  (d_OP_dot_slash_backslash x1 (Curry_Prelude.d_C_apply (d_C_no cd cs) x2 cd cs)
  cd cs) cd cs

d_C_nnf :: Dimacs.Curry_Types.C_Boolean -> Cover -> ConstStore
  -> Dimacs.Curry_Types.C_Boolean
d_C_nnf x1 cd cs = case x1 of
  Dimacs.Curry_Types.C_Var x2 -> Dimacs.Curry_Types.C_Var x2
  Dimacs.Curry_Types.C_Not x3 -> d_C__case_18 x1 x3 cd cs
  Dimacs.Curry_Types.C_And x8 -> Dimacs.Curry_Types.C_And (Curry_Prelude.d_C_map
    d_C_nnf x8 cd cs)
  Dimacs.Curry_Types.C_Or x9 -> Dimacs.Curry_Types.C_Or (Curry_Prelude.d_C_map
    d_C_nnf x9 cd cs)
  Dimacs.Curry_Types.Choice_C_Boolean d i l r -> narrow d i (d_C_nnf l cd cs)
    (d_C_nnf r cd cs)
  Dimacs.Curry_Types.Choices_C_Boolean d i xs -> narrows cs d i (\z -> d_C_nnf z
    cd cs) xs
  Dimacs.Curry_Types.Guard_C_Boolean d c e -> guardCons d c ((\x -> d_C_nnf e cd
    x) $! addCs c cs)
  Dimacs.Curry_Types.Fail_C_Boolean d info -> failCons d (traceFail
    "Dimacs.Build.nnf" [show x1] info)
  _ -> failCons cd (consFail "Dimacs.Build.nnf" (showCons x1))

d_C_cnf :: Dimacs.Curry_Types.C_Boolean -> Cover -> ConstStore
  -> Dimacs.Curry_Types.C_Boolean
d_C_cnf x1 cd cs = case x1 of
  Dimacs.Curry_Types.C_Var x2 -> Dimacs.Curry_Types.C_Or (Curry_Prelude.OP_Cons
    (Dimacs.Curry_Types.C_Var x2) Curry_Prelude.OP_List)
  Dimacs.Curry_Types.C_Not x3 -> Dimacs.Curry_Types.C_Or (Curry_Prelude.OP_Cons
    (Dimacs.Curry_Types.C_Not x3) Curry_Prelude.OP_List)
  Dimacs.Curry_Types.C_And x4 -> Dimacs.Curry_Types.C_And (Curry_Prelude.d_C_map
    d_C_cnf x4 cd cs)
  Dimacs.Curry_Types.C_Or x5 -> d_C__case_17 x5 cd cs
  Dimacs.Curry_Types.Choice_C_Boolean d i l r -> narrow d i (d_C_cnf l cd cs)
    (d_C_cnf r cd cs)
  Dimacs.Curry_Types.Choices_C_Boolean d i xs -> narrows cs d i (\z -> d_C_cnf z
    cd cs) xs
  Dimacs.Curry_Types.Guard_C_Boolean d c e -> guardCons d c ((\x -> d_C_cnf e cd
    x) $! addCs c cs)
  Dimacs.Curry_Types.Fail_C_Boolean d info -> failCons d (traceFail
    "Dimacs.Build.cnf" [show x1] info)
  _ -> failCons cd (consFail "Dimacs.Build.cnf" (showCons x1))

d_C_dist :: Dimacs.Curry_Types.C_Boolean -> Dimacs.Curry_Types.C_Boolean
  -> Cover -> ConstStore -> Dimacs.Curry_Types.C_Boolean
d_C_dist x1 x2 cd cs = d_C__case_15 x2 x1 (Curry_Prelude.OP_Tuple2 x1 x2) cd cs

d_C_flatten :: Dimacs.Curry_Types.C_Boolean -> Cover -> ConstStore
  -> Dimacs.Curry_Types.C_Boolean
d_C_flatten x1 cd cs = case x1 of
  Dimacs.Curry_Types.C_And x2 -> Dimacs.Curry_Types.C_And (d_C_flattenAnd x2 cd
    cs)
  Dimacs.Curry_Types.C_Or x3 -> Dimacs.Curry_Types.C_Or (d_C_flattenOr x3 cd cs)
  Dimacs.Curry_Types.C_Var x4 -> x1
  Dimacs.Curry_Types.C_Not x5 -> x1
  Dimacs.Curry_Types.Choice_C_Boolean d i l r -> narrow d i (d_C_flatten l cd
    cs) (d_C_flatten r cd cs)
  Dimacs.Curry_Types.Choices_C_Boolean d i xs -> narrows cs d i (\z ->
    d_C_flatten z cd cs) xs
  Dimacs.Curry_Types.Guard_C_Boolean d c e -> guardCons d c ((\x -> d_C_flatten
    e cd x) $! addCs c cs)
  Dimacs.Curry_Types.Fail_C_Boolean d info -> failCons d (traceFail
    "Dimacs.Build.flatten" [show x1] info)
  _ -> failCons cd (consFail "Dimacs.Build.flatten" (showCons x1))

d_C_flattenAnd :: Curry_Prelude.OP_List Dimacs.Curry_Types.C_Boolean -> Cover
  -> ConstStore -> Curry_Prelude.OP_List Dimacs.Curry_Types.C_Boolean
d_C_flattenAnd x1 cd cs = case x1 of
  Curry_Prelude.OP_List -> Curry_Prelude.OP_List
  Curry_Prelude.OP_Cons x2 x3 -> let x4 = Curry_Prelude.OP_Cons (d_C_flatten x2
                                       cd cs) (d_C_flattenAnd x3 cd cs)
    in d_C__case_4 x4 x3 x2 cd cs
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (d_C_flattenAnd l cd cs)
    (d_C_flattenAnd r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z -> d_C_flattenAnd z
    cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c ((\x -> d_C_flattenAnd e cd
    x) $! addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail
    "Dimacs.Build.flattenAnd" [show x1] info)
  _ -> failCons cd (consFail "Dimacs.Build.flattenAnd" (showCons x1))

d_C_flattenOr :: Curry_Prelude.OP_List Dimacs.Curry_Types.C_Boolean -> Cover
  -> ConstStore -> Curry_Prelude.OP_List Dimacs.Curry_Types.C_Boolean
d_C_flattenOr x1 cd cs = case x1 of
  Curry_Prelude.OP_List -> Curry_Prelude.OP_List
  Curry_Prelude.OP_Cons x2 x3 -> let x4 = Curry_Prelude.OP_Cons x2
                                       (d_C_flattenOr x3 cd cs)
    in d_C__case_3 x4 x3 x2 cd cs
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (d_C_flattenOr l cd cs)
    (d_C_flattenOr r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z -> d_C_flattenOr z
    cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c ((\x -> d_C_flattenOr e cd
    x) $! addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail
    "Dimacs.Build.flattenOr" [show x1] info)
  _ -> failCons cd (consFail "Dimacs.Build.flattenOr" (showCons x1))

d_C_nubB :: Dimacs.Curry_Types.C_Boolean -> Cover -> ConstStore
  -> Dimacs.Curry_Types.C_Boolean
d_C_nubB x1 cd cs = case x1 of
  Dimacs.Curry_Types.C_And x2 -> Dimacs.Curry_Types.C_And (Curry_Prelude.d_C_map
    d_C_nubB x2 cd cs)
  Dimacs.Curry_Types.C_Or x3 -> Dimacs.Curry_Types.C_Or (Data.Curry_List.d_C_nub
    Dimacs.Curry_Types.d_OP_uscore_inst_hash_Prelude_dot_Eq_hash_Dimacs_dot_Types_dot_Boolean_hash
    x3 cd cs)
  Dimacs.Curry_Types.C_Var x4 -> x1
  Dimacs.Curry_Types.C_Not x5 -> x1
  Dimacs.Curry_Types.Choice_C_Boolean d i l r -> narrow d i (d_C_nubB l cd cs)
    (d_C_nubB r cd cs)
  Dimacs.Curry_Types.Choices_C_Boolean d i xs -> narrows cs d i (\z -> d_C_nubB
    z cd cs) xs
  Dimacs.Curry_Types.Guard_C_Boolean d c e -> guardCons d c ((\x -> d_C_nubB e
    cd x) $! addCs c cs)
  Dimacs.Curry_Types.Fail_C_Boolean d info -> failCons d (traceFail
    "Dimacs.Build.nubB" [show x1] info)
  _ -> failCons cd (consFail "Dimacs.Build.nubB" (showCons x1))

d_C_toCNF :: Cover -> ConstStore -> Dimacs.Curry_Types.C_Boolean -> Cover
  -> ConstStore -> Dimacs.Curry_Types.C_Boolean
d_C_toCNF cd cs = Curry_Prelude.d_OP_dot d_C_filterTauts (Curry_Prelude.d_OP_dot
  d_C_nubB (Curry_Prelude.d_OP_dot d_C_flatten (Curry_Prelude.d_OP_dot d_C_cnf
  d_C_nnf cd cs) cd cs) cd cs) cd cs

d_C_filterTauts :: Dimacs.Curry_Types.C_Boolean -> Cover -> ConstStore
  -> Dimacs.Curry_Types.C_Boolean
d_C_filterTauts x1 cd cs = case x1 of
  Dimacs.Curry_Types.C_And x2 -> Curry_Prelude.d_OP_dollar (acceptCs id
    Dimacs.Curry_Types.C_And) (Curry_Prelude.d_C_filter (Curry_Prelude.d_OP_dot
    Curry_Prelude.d_C_not d_C_isTaut cd cs) x2 cd cs) cd cs
  Dimacs.Curry_Types.C_Var x3 -> x1
  Dimacs.Curry_Types.C_Not x4 -> x1
  Dimacs.Curry_Types.C_Or x5 -> x1
  Dimacs.Curry_Types.Choice_C_Boolean d i l r -> narrow d i (d_C_filterTauts l
    cd cs) (d_C_filterTauts r cd cs)
  Dimacs.Curry_Types.Choices_C_Boolean d i xs -> narrows cs d i (\z ->
    d_C_filterTauts z cd cs) xs
  Dimacs.Curry_Types.Guard_C_Boolean d c e -> guardCons d c ((\x ->
    d_C_filterTauts e cd x) $! addCs c cs)
  Dimacs.Curry_Types.Fail_C_Boolean d info -> failCons d (traceFail
    "Dimacs.Build.filterTauts" [show x1] info)
  _ -> failCons cd (consFail "Dimacs.Build.filterTauts" (showCons x1))

d_C_isTaut :: Dimacs.Curry_Types.C_Boolean -> Cover -> ConstStore
  -> Curry_Prelude.C_Bool
d_C_isTaut x1 cd cs = let x2 = Curry_Prelude.C_False in d_C__case_2 x2 x1 cd cs

d_OP_isTaut_dot_containsInverted_dot_198 :: Dimacs.Curry_Types.C_Boolean
  -> Curry_Prelude.OP_List Dimacs.Curry_Types.C_Boolean -> Cover -> ConstStore
  -> Curry_Prelude.C_Bool
d_OP_isTaut_dot_containsInverted_dot_198 x1 x2 cd cs =
  let x3 = Curry_Prelude.C_False in d_C__case_1 x3 x2 x1 cd cs

d_OP_isTaut_dot_isTaut_tick_dot_198 :: Curry_Prelude.OP_List
  Dimacs.Curry_Types.C_Boolean -> Cover -> ConstStore -> Curry_Prelude.C_Bool
d_OP_isTaut_dot_isTaut_tick_dot_198 x1 cd cs = case x1 of
  Curry_Prelude.OP_List -> Curry_Prelude.C_False
  Curry_Prelude.OP_Cons x2 x3 -> Curry_Prelude.d_OP_bar_bar
    (d_OP_isTaut_dot_containsInverted_dot_198 x2 x3 cd cs)
    (d_OP_isTaut_dot_isTaut_tick_dot_198 x3 cd cs) cd cs
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i
    (d_OP_isTaut_dot_isTaut_tick_dot_198 l cd cs)
    (d_OP_isTaut_dot_isTaut_tick_dot_198 r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z ->
    d_OP_isTaut_dot_isTaut_tick_dot_198 z cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c ((\x ->
    d_OP_isTaut_dot_isTaut_tick_dot_198 e cd x) $! addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail
    "Dimacs.Build.isTaut.isTaut'.198" [show x1] info)
  _ -> failCons cd (consFail "Dimacs.Build.isTaut.isTaut'.198" (showCons x1))

d_C__case_30 :: Dimacs.Curry_Types.C_Boolean -> Dimacs.Curry_Types.C_Boolean
  -> Curry_Prelude.OP_Tuple2 Dimacs.Curry_Types.C_Boolean
  Dimacs.Curry_Types.C_Boolean -> Cover -> ConstStore
  -> Dimacs.Curry_Types.C_Boolean
d_C__case_30 x2 x1 x5 cd cs = case x5 of
  Curry_Prelude.OP_Tuple2 x3 x4 -> d_C__case_29 x4 x1 x2 x3 cd cs
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i (d_C__case_30 x2 x1 l cd
    cs) (d_C__case_30 x2 x1 r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z -> d_C__case_30
    x2 x1 z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c ((\x -> d_C__case_30 x2
    x1 e cd x) $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "Dimacs.Build._case_30" [show x2, show x1, show x5] info)
  _ -> failCons cd (consFail "Dimacs.Build._case_30" (showCons x5))

d_C__case_29 :: Dimacs.Curry_Types.C_Boolean -> Dimacs.Curry_Types.C_Boolean
  -> Dimacs.Curry_Types.C_Boolean -> Dimacs.Curry_Types.C_Boolean -> Cover
  -> ConstStore -> Dimacs.Curry_Types.C_Boolean
d_C__case_29 x4 x1 x2 x3 cd cs = case x3 of
  Dimacs.Curry_Types.C_Var x5 -> d_C__case_28 x2 x1 x4 cd cs
  Dimacs.Curry_Types.C_Not x10 -> d_C__case_27 x2 x1 x4 cd cs
  Dimacs.Curry_Types.C_And x15 -> d_C__case_26 x15 x2 x1 x4 cd cs
  Dimacs.Curry_Types.C_Or x20 -> d_C__case_25 x1 x2 x4 cd cs
  Dimacs.Curry_Types.Choice_C_Boolean d i l r -> narrow d i (d_C__case_29 x4 x1
    x2 l cd cs) (d_C__case_29 x4 x1 x2 r cd cs)
  Dimacs.Curry_Types.Choices_C_Boolean d i xs -> narrows cs d i (\z ->
    d_C__case_29 x4 x1 x2 z cd cs) xs
  Dimacs.Curry_Types.Guard_C_Boolean d c e -> guardCons d c ((\x -> d_C__case_29
    x4 x1 x2 e cd x) $! addCs c cs)
  Dimacs.Curry_Types.Fail_C_Boolean d info -> failCons d (traceFail
    "Dimacs.Build._case_29" [show x4, show x1, show x2, show x3] info)
  _ -> failCons cd (consFail "Dimacs.Build._case_29" (showCons x3))

d_C__case_25 :: Dimacs.Curry_Types.C_Boolean -> Dimacs.Curry_Types.C_Boolean
  -> Dimacs.Curry_Types.C_Boolean -> Cover -> ConstStore
  -> Dimacs.Curry_Types.C_Boolean
d_C__case_25 x1 x2 x4 cd cs = case x4 of
  Dimacs.Curry_Types.C_Var x21 -> d_OP_dot_slash_backslash x2 x1 cd cs
  Dimacs.Curry_Types.C_Not x22 -> d_OP_dot_slash_backslash x2 x1 cd cs
  Dimacs.Curry_Types.C_Or x23 -> Dimacs.Curry_Types.C_And (Curry_Prelude.OP_Cons
    x1 (Curry_Prelude.OP_Cons x2 Curry_Prelude.OP_List))
  Dimacs.Curry_Types.C_And x24 -> d_OP_dot_slash_backslash x2 x1 cd cs
  Dimacs.Curry_Types.Choice_C_Boolean d i l r -> narrow d i (d_C__case_25 x1 x2
    l cd cs) (d_C__case_25 x1 x2 r cd cs)
  Dimacs.Curry_Types.Choices_C_Boolean d i xs -> narrows cs d i (\z ->
    d_C__case_25 x1 x2 z cd cs) xs
  Dimacs.Curry_Types.Guard_C_Boolean d c e -> guardCons d c ((\x -> d_C__case_25
    x1 x2 e cd x) $! addCs c cs)
  Dimacs.Curry_Types.Fail_C_Boolean d info -> failCons d (traceFail
    "Dimacs.Build._case_25" [show x1, show x2, show x4] info)
  _ -> failCons cd (consFail "Dimacs.Build._case_25" (showCons x4))

d_C__case_26 :: Curry_Prelude.OP_List Dimacs.Curry_Types.C_Boolean
  -> Dimacs.Curry_Types.C_Boolean -> Dimacs.Curry_Types.C_Boolean
  -> Dimacs.Curry_Types.C_Boolean -> Cover -> ConstStore
  -> Dimacs.Curry_Types.C_Boolean
d_C__case_26 x15 x2 x1 x4 cd cs = case x4 of
  Dimacs.Curry_Types.C_Var x16 -> d_OP_dot_slash_backslash x2 x1 cd cs
  Dimacs.Curry_Types.C_Not x17 -> d_OP_dot_slash_backslash x2 x1 cd cs
  Dimacs.Curry_Types.C_And x18 -> Curry_Prelude.d_OP_dollar (acceptCs id
    Dimacs.Curry_Types.C_And) (Curry_Prelude.d_OP_plus_plus x15 x18 cd cs) cd cs
  Dimacs.Curry_Types.C_Or x19 -> Curry_Prelude.d_OP_dollar (acceptCs id
    Dimacs.Curry_Types.C_And) (Curry_Prelude.OP_Cons x2 x15) cd cs
  Dimacs.Curry_Types.Choice_C_Boolean d i l r -> narrow d i (d_C__case_26 x15 x2
    x1 l cd cs) (d_C__case_26 x15 x2 x1 r cd cs)
  Dimacs.Curry_Types.Choices_C_Boolean d i xs -> narrows cs d i (\z ->
    d_C__case_26 x15 x2 x1 z cd cs) xs
  Dimacs.Curry_Types.Guard_C_Boolean d c e -> guardCons d c ((\x -> d_C__case_26
    x15 x2 x1 e cd x) $! addCs c cs)
  Dimacs.Curry_Types.Fail_C_Boolean d info -> failCons d (traceFail
    "Dimacs.Build._case_26" [show x15, show x2, show x1, show x4] info)
  _ -> failCons cd (consFail "Dimacs.Build._case_26" (showCons x4))

d_C__case_27 :: Dimacs.Curry_Types.C_Boolean -> Dimacs.Curry_Types.C_Boolean
  -> Dimacs.Curry_Types.C_Boolean -> Cover -> ConstStore
  -> Dimacs.Curry_Types.C_Boolean
d_C__case_27 x2 x1 x4 cd cs = case x4 of
  Dimacs.Curry_Types.C_Var x11 -> d_OP_dot_slash_backslash x2 x1 cd cs
  Dimacs.Curry_Types.C_Not x12 -> Dimacs.Curry_Types.C_And
    (Curry_Prelude.OP_Cons x1 (Curry_Prelude.OP_Cons x2 Curry_Prelude.OP_List))
  Dimacs.Curry_Types.C_And x13 -> Curry_Prelude.d_OP_dollar (acceptCs id
    Dimacs.Curry_Types.C_And) (Curry_Prelude.OP_Cons x1 x13) cd cs
  Dimacs.Curry_Types.C_Or x14 -> Dimacs.Curry_Types.C_And (Curry_Prelude.OP_Cons
    x1 (Curry_Prelude.OP_Cons x2 Curry_Prelude.OP_List))
  Dimacs.Curry_Types.Choice_C_Boolean d i l r -> narrow d i (d_C__case_27 x2 x1
    l cd cs) (d_C__case_27 x2 x1 r cd cs)
  Dimacs.Curry_Types.Choices_C_Boolean d i xs -> narrows cs d i (\z ->
    d_C__case_27 x2 x1 z cd cs) xs
  Dimacs.Curry_Types.Guard_C_Boolean d c e -> guardCons d c ((\x -> d_C__case_27
    x2 x1 e cd x) $! addCs c cs)
  Dimacs.Curry_Types.Fail_C_Boolean d info -> failCons d (traceFail
    "Dimacs.Build._case_27" [show x2, show x1, show x4] info)
  _ -> failCons cd (consFail "Dimacs.Build._case_27" (showCons x4))

d_C__case_28 :: Dimacs.Curry_Types.C_Boolean -> Dimacs.Curry_Types.C_Boolean
  -> Dimacs.Curry_Types.C_Boolean -> Cover -> ConstStore
  -> Dimacs.Curry_Types.C_Boolean
d_C__case_28 x2 x1 x4 cd cs = case x4 of
  Dimacs.Curry_Types.C_Var x6 -> Dimacs.Curry_Types.C_And (Curry_Prelude.OP_Cons
    x1 (Curry_Prelude.OP_Cons x2 Curry_Prelude.OP_List))
  Dimacs.Curry_Types.C_Not x7 -> Dimacs.Curry_Types.C_And (Curry_Prelude.OP_Cons
    x1 (Curry_Prelude.OP_Cons x2 Curry_Prelude.OP_List))
  Dimacs.Curry_Types.C_And x8 -> Curry_Prelude.d_OP_dollar (acceptCs id
    Dimacs.Curry_Types.C_And) (Curry_Prelude.OP_Cons x1 x8) cd cs
  Dimacs.Curry_Types.C_Or x9 -> Dimacs.Curry_Types.C_And (Curry_Prelude.OP_Cons
    x1 (Curry_Prelude.OP_Cons x2 Curry_Prelude.OP_List))
  Dimacs.Curry_Types.Choice_C_Boolean d i l r -> narrow d i (d_C__case_28 x2 x1
    l cd cs) (d_C__case_28 x2 x1 r cd cs)
  Dimacs.Curry_Types.Choices_C_Boolean d i xs -> narrows cs d i (\z ->
    d_C__case_28 x2 x1 z cd cs) xs
  Dimacs.Curry_Types.Guard_C_Boolean d c e -> guardCons d c ((\x -> d_C__case_28
    x2 x1 e cd x) $! addCs c cs)
  Dimacs.Curry_Types.Fail_C_Boolean d info -> failCons d (traceFail
    "Dimacs.Build._case_28" [show x2, show x1, show x4] info)
  _ -> failCons cd (consFail "Dimacs.Build._case_28" (showCons x4))

d_C__case_24 :: Dimacs.Curry_Types.C_Boolean -> Dimacs.Curry_Types.C_Boolean
  -> Curry_Prelude.OP_Tuple2 Dimacs.Curry_Types.C_Boolean
  Dimacs.Curry_Types.C_Boolean -> Cover -> ConstStore
  -> Dimacs.Curry_Types.C_Boolean
d_C__case_24 x2 x1 x5 cd cs = case x5 of
  Curry_Prelude.OP_Tuple2 x3 x4 -> d_C__case_23 x4 x1 x2 x3 cd cs
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i (d_C__case_24 x2 x1 l cd
    cs) (d_C__case_24 x2 x1 r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z -> d_C__case_24
    x2 x1 z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c ((\x -> d_C__case_24 x2
    x1 e cd x) $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "Dimacs.Build._case_24" [show x2, show x1, show x5] info)
  _ -> failCons cd (consFail "Dimacs.Build._case_24" (showCons x5))

d_C__case_23 :: Dimacs.Curry_Types.C_Boolean -> Dimacs.Curry_Types.C_Boolean
  -> Dimacs.Curry_Types.C_Boolean -> Dimacs.Curry_Types.C_Boolean -> Cover
  -> ConstStore -> Dimacs.Curry_Types.C_Boolean
d_C__case_23 x4 x1 x2 x3 cd cs = case x3 of
  Dimacs.Curry_Types.C_Var x5 -> d_C__case_22 x1 x2 x4 cd cs
  Dimacs.Curry_Types.C_Not x10 -> d_C__case_21 x1 x2 x4 cd cs
  Dimacs.Curry_Types.C_And x15 -> d_C__case_20 x1 x2 x4 cd cs
  Dimacs.Curry_Types.C_Or x20 -> d_C__case_19 x1 x2 x20 x4 cd cs
  Dimacs.Curry_Types.Choice_C_Boolean d i l r -> narrow d i (d_C__case_23 x4 x1
    x2 l cd cs) (d_C__case_23 x4 x1 x2 r cd cs)
  Dimacs.Curry_Types.Choices_C_Boolean d i xs -> narrows cs d i (\z ->
    d_C__case_23 x4 x1 x2 z cd cs) xs
  Dimacs.Curry_Types.Guard_C_Boolean d c e -> guardCons d c ((\x -> d_C__case_23
    x4 x1 x2 e cd x) $! addCs c cs)
  Dimacs.Curry_Types.Fail_C_Boolean d info -> failCons d (traceFail
    "Dimacs.Build._case_23" [show x4, show x1, show x2, show x3] info)
  _ -> failCons cd (consFail "Dimacs.Build._case_23" (showCons x3))

d_C__case_19 :: Dimacs.Curry_Types.C_Boolean -> Dimacs.Curry_Types.C_Boolean
  -> Curry_Prelude.OP_List Dimacs.Curry_Types.C_Boolean
  -> Dimacs.Curry_Types.C_Boolean -> Cover -> ConstStore
  -> Dimacs.Curry_Types.C_Boolean
d_C__case_19 x1 x2 x20 x4 cd cs = case x4 of
  Dimacs.Curry_Types.C_Var x21 -> d_OP_dot_backslash_slash x2 x1 cd cs
  Dimacs.Curry_Types.C_Not x22 -> d_OP_dot_slash_backslash x2 x1 cd cs
  Dimacs.Curry_Types.C_Or x23 -> Curry_Prelude.d_OP_dollar (acceptCs id
    Dimacs.Curry_Types.C_Or) (Curry_Prelude.d_OP_plus_plus x20 x23 cd cs) cd cs
  Dimacs.Curry_Types.C_And x24 -> d_OP_dot_backslash_slash x2 x1 cd cs
  Dimacs.Curry_Types.Choice_C_Boolean d i l r -> narrow d i (d_C__case_19 x1 x2
    x20 l cd cs) (d_C__case_19 x1 x2 x20 r cd cs)
  Dimacs.Curry_Types.Choices_C_Boolean d i xs -> narrows cs d i (\z ->
    d_C__case_19 x1 x2 x20 z cd cs) xs
  Dimacs.Curry_Types.Guard_C_Boolean d c e -> guardCons d c ((\x -> d_C__case_19
    x1 x2 x20 e cd x) $! addCs c cs)
  Dimacs.Curry_Types.Fail_C_Boolean d info -> failCons d (traceFail
    "Dimacs.Build._case_19" [show x1, show x2, show x20, show x4] info)
  _ -> failCons cd (consFail "Dimacs.Build._case_19" (showCons x4))

d_C__case_20 :: Dimacs.Curry_Types.C_Boolean -> Dimacs.Curry_Types.C_Boolean
  -> Dimacs.Curry_Types.C_Boolean -> Cover -> ConstStore
  -> Dimacs.Curry_Types.C_Boolean
d_C__case_20 x1 x2 x4 cd cs = case x4 of
  Dimacs.Curry_Types.C_Var x16 -> d_OP_dot_backslash_slash x2 x1 cd cs
  Dimacs.Curry_Types.C_Not x17 -> d_OP_dot_slash_backslash x2 x1 cd cs
  Dimacs.Curry_Types.C_And x18 -> Dimacs.Curry_Types.C_Or (Curry_Prelude.OP_Cons
    x1 (Curry_Prelude.OP_Cons x2 Curry_Prelude.OP_List))
  Dimacs.Curry_Types.C_Or x19 -> Curry_Prelude.d_OP_dollar (acceptCs id
    Dimacs.Curry_Types.C_Or) (Curry_Prelude.OP_Cons x1 x19) cd cs
  Dimacs.Curry_Types.Choice_C_Boolean d i l r -> narrow d i (d_C__case_20 x1 x2
    l cd cs) (d_C__case_20 x1 x2 r cd cs)
  Dimacs.Curry_Types.Choices_C_Boolean d i xs -> narrows cs d i (\z ->
    d_C__case_20 x1 x2 z cd cs) xs
  Dimacs.Curry_Types.Guard_C_Boolean d c e -> guardCons d c ((\x -> d_C__case_20
    x1 x2 e cd x) $! addCs c cs)
  Dimacs.Curry_Types.Fail_C_Boolean d info -> failCons d (traceFail
    "Dimacs.Build._case_20" [show x1, show x2, show x4] info)
  _ -> failCons cd (consFail "Dimacs.Build._case_20" (showCons x4))

d_C__case_21 :: Dimacs.Curry_Types.C_Boolean -> Dimacs.Curry_Types.C_Boolean
  -> Dimacs.Curry_Types.C_Boolean -> Cover -> ConstStore
  -> Dimacs.Curry_Types.C_Boolean
d_C__case_21 x1 x2 x4 cd cs = case x4 of
  Dimacs.Curry_Types.C_Var x11 -> d_OP_dot_backslash_slash x2 x1 cd cs
  Dimacs.Curry_Types.C_Not x12 -> Dimacs.Curry_Types.C_Or (Curry_Prelude.OP_Cons
    x1 (Curry_Prelude.OP_Cons x2 Curry_Prelude.OP_List))
  Dimacs.Curry_Types.C_And x13 -> Dimacs.Curry_Types.C_Or (Curry_Prelude.OP_Cons
    x1 (Curry_Prelude.OP_Cons x2 Curry_Prelude.OP_List))
  Dimacs.Curry_Types.C_Or x14 -> Curry_Prelude.d_OP_dollar (acceptCs id
    Dimacs.Curry_Types.C_Or) (Curry_Prelude.OP_Cons x1 x14) cd cs
  Dimacs.Curry_Types.Choice_C_Boolean d i l r -> narrow d i (d_C__case_21 x1 x2
    l cd cs) (d_C__case_21 x1 x2 r cd cs)
  Dimacs.Curry_Types.Choices_C_Boolean d i xs -> narrows cs d i (\z ->
    d_C__case_21 x1 x2 z cd cs) xs
  Dimacs.Curry_Types.Guard_C_Boolean d c e -> guardCons d c ((\x -> d_C__case_21
    x1 x2 e cd x) $! addCs c cs)
  Dimacs.Curry_Types.Fail_C_Boolean d info -> failCons d (traceFail
    "Dimacs.Build._case_21" [show x1, show x2, show x4] info)
  _ -> failCons cd (consFail "Dimacs.Build._case_21" (showCons x4))

d_C__case_22 :: Dimacs.Curry_Types.C_Boolean -> Dimacs.Curry_Types.C_Boolean
  -> Dimacs.Curry_Types.C_Boolean -> Cover -> ConstStore
  -> Dimacs.Curry_Types.C_Boolean
d_C__case_22 x1 x2 x4 cd cs = case x4 of
  Dimacs.Curry_Types.C_Var x6 -> Dimacs.Curry_Types.C_Or (Curry_Prelude.OP_Cons
    x1 (Curry_Prelude.OP_Cons x2 Curry_Prelude.OP_List))
  Dimacs.Curry_Types.C_Not x7 -> Dimacs.Curry_Types.C_Or (Curry_Prelude.OP_Cons
    x1 (Curry_Prelude.OP_Cons x2 Curry_Prelude.OP_List))
  Dimacs.Curry_Types.C_And x8 -> Dimacs.Curry_Types.C_Or (Curry_Prelude.OP_Cons
    x1 (Curry_Prelude.OP_Cons x2 Curry_Prelude.OP_List))
  Dimacs.Curry_Types.C_Or x9 -> Curry_Prelude.d_OP_dollar (acceptCs id
    Dimacs.Curry_Types.C_Or) (Curry_Prelude.OP_Cons x1 x9) cd cs
  Dimacs.Curry_Types.Choice_C_Boolean d i l r -> narrow d i (d_C__case_22 x1 x2
    l cd cs) (d_C__case_22 x1 x2 r cd cs)
  Dimacs.Curry_Types.Choices_C_Boolean d i xs -> narrows cs d i (\z ->
    d_C__case_22 x1 x2 z cd cs) xs
  Dimacs.Curry_Types.Guard_C_Boolean d c e -> guardCons d c ((\x -> d_C__case_22
    x1 x2 e cd x) $! addCs c cs)
  Dimacs.Curry_Types.Fail_C_Boolean d info -> failCons d (traceFail
    "Dimacs.Build._case_22" [show x1, show x2, show x4] info)
  _ -> failCons cd (consFail "Dimacs.Build._case_22" (showCons x4))

d_C__case_18 :: Dimacs.Curry_Types.C_Boolean -> Dimacs.Curry_Types.C_Boolean
  -> Cover -> ConstStore -> Dimacs.Curry_Types.C_Boolean
d_C__case_18 x1 x3 cd cs = case x3 of
  Dimacs.Curry_Types.C_Var x4 -> x1
  Dimacs.Curry_Types.C_Not x5 -> d_C_nnf x5 cd cs
  Dimacs.Curry_Types.C_And x6 -> Dimacs.Curry_Types.C_Or (Curry_Prelude.d_C_map
    (Curry_Prelude.d_OP_dot d_C_nnf (acceptCs id Dimacs.Curry_Types.C_Not) cd
    cs) x6 cd cs)
  Dimacs.Curry_Types.C_Or x7 -> Dimacs.Curry_Types.C_And (Curry_Prelude.d_C_map
    (Curry_Prelude.d_OP_dot d_C_nnf (acceptCs id Dimacs.Curry_Types.C_Not) cd
    cs) x7 cd cs)
  Dimacs.Curry_Types.Choice_C_Boolean d i l r -> narrow d i (d_C__case_18 x1 l
    cd cs) (d_C__case_18 x1 r cd cs)
  Dimacs.Curry_Types.Choices_C_Boolean d i xs -> narrows cs d i (\z ->
    d_C__case_18 x1 z cd cs) xs
  Dimacs.Curry_Types.Guard_C_Boolean d c e -> guardCons d c ((\x -> d_C__case_18
    x1 e cd x) $! addCs c cs)
  Dimacs.Curry_Types.Fail_C_Boolean d info -> failCons d (traceFail
    "Dimacs.Build._case_18" [show x1, show x3] info)
  _ -> failCons cd (consFail "Dimacs.Build._case_18" (showCons x3))

d_C__case_17 :: Curry_Prelude.OP_List Dimacs.Curry_Types.C_Boolean -> Cover
  -> ConstStore -> Dimacs.Curry_Types.C_Boolean
d_C__case_17 x5 cd cs = case x5 of
  Curry_Prelude.OP_List -> Dimacs.Curry_Types.C_Or Curry_Prelude.OP_List
  Curry_Prelude.OP_Cons x6 x7 -> d_C__case_16 x6 x7 cd cs
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (d_C__case_17 l cd cs)
    (d_C__case_17 r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z -> d_C__case_17 z
    cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c ((\x -> d_C__case_17 e cd
    x) $! addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail
    "Dimacs.Build._case_17" [show x5] info)
  _ -> failCons cd (consFail "Dimacs.Build._case_17" (showCons x5))

d_C__case_16 :: Dimacs.Curry_Types.C_Boolean -> Curry_Prelude.OP_List
  Dimacs.Curry_Types.C_Boolean -> Cover -> ConstStore
  -> Dimacs.Curry_Types.C_Boolean
d_C__case_16 x6 x7 cd cs = case x7 of
  Curry_Prelude.OP_List -> d_C_cnf x6 cd cs
  Curry_Prelude.OP_Cons x8 x9 -> d_C_dist (d_C_cnf x6 cd cs) (d_C_cnf
    (Dimacs.Curry_Types.C_Or (Curry_Prelude.OP_Cons x8 x9)) cd cs) cd cs
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (d_C__case_16 x6 l cd cs)
    (d_C__case_16 x6 r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z -> d_C__case_16 x6
    z cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c ((\x -> d_C__case_16 x6 e
    cd x) $! addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail
    "Dimacs.Build._case_16" [show x6, show x7] info)
  _ -> failCons cd (consFail "Dimacs.Build._case_16" (showCons x7))

d_C__case_15 :: Dimacs.Curry_Types.C_Boolean -> Dimacs.Curry_Types.C_Boolean
  -> Curry_Prelude.OP_Tuple2 Dimacs.Curry_Types.C_Boolean
  Dimacs.Curry_Types.C_Boolean -> Cover -> ConstStore
  -> Dimacs.Curry_Types.C_Boolean
d_C__case_15 x2 x1 x7 cd cs = case x7 of
  Curry_Prelude.OP_Tuple2 x3 x4 -> let x5 = let x6 = Dimacs.Curry_Types.C_Or
                                                  (Curry_Prelude.OP_Cons x3
                                                  (Curry_Prelude.OP_Cons x4
                                                  Curry_Prelude.OP_List))
                                         in d_C__case_7 x6 x3 x4 cd cs
    in d_C__case_14 x5 x4 x3 cd cs
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i (d_C__case_15 x2 x1 l cd
    cs) (d_C__case_15 x2 x1 r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z -> d_C__case_15
    x2 x1 z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c ((\x -> d_C__case_15 x2
    x1 e cd x) $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "Dimacs.Build._case_15" [show x2, show x1, show x7] info)
  _ -> failCons cd (consFail "Dimacs.Build._case_15" (showCons x7))

d_C__case_7 :: Dimacs.Curry_Types.C_Boolean -> Dimacs.Curry_Types.C_Boolean
  -> Dimacs.Curry_Types.C_Boolean -> Cover -> ConstStore
  -> Dimacs.Curry_Types.C_Boolean
d_C__case_7 x6 x3 x4 cd cs = case x4 of
  Dimacs.Curry_Types.C_And x7 -> d_C__case_6 x3 x7 cd cs
  Dimacs.Curry_Types.C_Var x12 -> x6
  Dimacs.Curry_Types.C_Not x13 -> x6
  Dimacs.Curry_Types.C_Or x14 -> x6
  Dimacs.Curry_Types.Choice_C_Boolean d i l r -> narrow d i (d_C__case_7 x6 x3 l
    cd cs) (d_C__case_7 x6 x3 r cd cs)
  Dimacs.Curry_Types.Choices_C_Boolean d i xs -> narrows cs d i (\z ->
    d_C__case_7 x6 x3 z cd cs) xs
  Dimacs.Curry_Types.Guard_C_Boolean d c e -> guardCons d c ((\x -> d_C__case_7
    x6 x3 e cd x) $! addCs c cs)
  Dimacs.Curry_Types.Fail_C_Boolean d info -> failCons d (traceFail
    "Dimacs.Build._case_7" [show x6, show x3, show x4] info)
  _ -> failCons cd (consFail "Dimacs.Build._case_7" (showCons x4))

d_C__case_6 :: Dimacs.Curry_Types.C_Boolean -> Curry_Prelude.OP_List
  Dimacs.Curry_Types.C_Boolean -> Cover -> ConstStore
  -> Dimacs.Curry_Types.C_Boolean
d_C__case_6 x3 x7 cd cs = case x7 of
  Curry_Prelude.OP_List -> Dimacs.Curry_Types.C_And Curry_Prelude.OP_List
  Curry_Prelude.OP_Cons x8 x9 -> d_C__case_5 x3 x8 x9 cd cs
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (d_C__case_6 x3 l cd cs)
    (d_C__case_6 x3 r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z -> d_C__case_6 x3 z
    cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c ((\x -> d_C__case_6 x3 e cd
    x) $! addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail
    "Dimacs.Build._case_6" [show x3, show x7] info)
  _ -> failCons cd (consFail "Dimacs.Build._case_6" (showCons x7))

d_C__case_5 :: Dimacs.Curry_Types.C_Boolean -> Dimacs.Curry_Types.C_Boolean
  -> Curry_Prelude.OP_List Dimacs.Curry_Types.C_Boolean -> Cover -> ConstStore
  -> Dimacs.Curry_Types.C_Boolean
d_C__case_5 x3 x8 x9 cd cs = case x9 of
  Curry_Prelude.OP_List -> d_C_dist x3 x8 cd cs
  Curry_Prelude.OP_Cons x10 x11 -> Dimacs.Curry_Types.C_And
    (Curry_Prelude.OP_Cons (d_C_dist x3 x8 cd cs) (Curry_Prelude.OP_Cons
    (d_C_dist x3 (Dimacs.Curry_Types.C_And x9) cd cs) Curry_Prelude.OP_List))
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (d_C__case_5 x3 x8 l cd cs)
    (d_C__case_5 x3 x8 r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z -> d_C__case_5 x3
    x8 z cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c ((\x -> d_C__case_5 x3 x8 e
    cd x) $! addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail
    "Dimacs.Build._case_5" [show x3, show x8, show x9] info)
  _ -> failCons cd (consFail "Dimacs.Build._case_5" (showCons x9))

d_C__case_14 :: Dimacs.Curry_Types.C_Boolean -> Dimacs.Curry_Types.C_Boolean
  -> Dimacs.Curry_Types.C_Boolean -> Cover -> ConstStore
  -> Dimacs.Curry_Types.C_Boolean
d_C__case_14 x5 x4 x3 cd cs = case x3 of
  Dimacs.Curry_Types.C_And x15 -> d_C__case_13 x4 x3 x15 cd cs
  Dimacs.Curry_Types.C_Var x31 -> x5
  Dimacs.Curry_Types.C_Not x32 -> x5
  Dimacs.Curry_Types.C_Or x33 -> x5
  Dimacs.Curry_Types.Choice_C_Boolean d i l r -> narrow d i (d_C__case_14 x5 x4
    l cd cs) (d_C__case_14 x5 x4 r cd cs)
  Dimacs.Curry_Types.Choices_C_Boolean d i xs -> narrows cs d i (\z ->
    d_C__case_14 x5 x4 z cd cs) xs
  Dimacs.Curry_Types.Guard_C_Boolean d c e -> guardCons d c ((\x -> d_C__case_14
    x5 x4 e cd x) $! addCs c cs)
  Dimacs.Curry_Types.Fail_C_Boolean d info -> failCons d (traceFail
    "Dimacs.Build._case_14" [show x5, show x4, show x3] info)
  _ -> failCons cd (consFail "Dimacs.Build._case_14" (showCons x3))

d_C__case_13 :: Dimacs.Curry_Types.C_Boolean -> Dimacs.Curry_Types.C_Boolean
  -> Curry_Prelude.OP_List Dimacs.Curry_Types.C_Boolean -> Cover -> ConstStore
  -> Dimacs.Curry_Types.C_Boolean
d_C__case_13 x4 x3 x15 cd cs = case x15 of
  Curry_Prelude.OP_List -> Dimacs.Curry_Types.C_And Curry_Prelude.OP_List
  Curry_Prelude.OP_Cons x16 x17 -> let x18 = d_C__case_8 x4 x16 x17 cd cs
    in d_C__case_12 x18 x17 x16 x3 x4 cd cs
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (d_C__case_13 x4 x3 l cd
    cs) (d_C__case_13 x4 x3 r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z -> d_C__case_13 x4
    x3 z cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c ((\x -> d_C__case_13 x4 x3
    e cd x) $! addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail
    "Dimacs.Build._case_13" [show x4, show x3, show x15] info)
  _ -> failCons cd (consFail "Dimacs.Build._case_13" (showCons x15))

d_C__case_8 :: Dimacs.Curry_Types.C_Boolean -> Dimacs.Curry_Types.C_Boolean
  -> Curry_Prelude.OP_List Dimacs.Curry_Types.C_Boolean -> Cover -> ConstStore
  -> Dimacs.Curry_Types.C_Boolean
d_C__case_8 x4 x16 x17 cd cs = case x17 of
  Curry_Prelude.OP_List -> d_C_dist x16 x4 cd cs
  Curry_Prelude.OP_Cons x19 x20 -> Dimacs.Curry_Types.C_And
    (Curry_Prelude.OP_Cons (d_C_dist x16 x4 cd cs) (Curry_Prelude.OP_Cons
    (d_C_dist (Dimacs.Curry_Types.C_And x17) x4 cd cs) Curry_Prelude.OP_List))
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (d_C__case_8 x4 x16 l cd
    cs) (d_C__case_8 x4 x16 r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z -> d_C__case_8 x4
    x16 z cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c ((\x -> d_C__case_8 x4 x16
    e cd x) $! addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail
    "Dimacs.Build._case_8" [show x4, show x16, show x17] info)
  _ -> failCons cd (consFail "Dimacs.Build._case_8" (showCons x17))

d_C__case_12 :: Dimacs.Curry_Types.C_Boolean -> Curry_Prelude.OP_List
  Dimacs.Curry_Types.C_Boolean -> Dimacs.Curry_Types.C_Boolean
  -> Dimacs.Curry_Types.C_Boolean -> Dimacs.Curry_Types.C_Boolean -> Cover
  -> ConstStore -> Dimacs.Curry_Types.C_Boolean
d_C__case_12 x18 x17 x16 x3 x4 cd cs = case x4 of
  Dimacs.Curry_Types.C_And x21 -> d_C__case_11 x17 x4 x16 x3 x21 cd cs
  Dimacs.Curry_Types.C_Var x28 -> x18
  Dimacs.Curry_Types.C_Not x29 -> x18
  Dimacs.Curry_Types.C_Or x30 -> x18
  Dimacs.Curry_Types.Choice_C_Boolean d i l r -> narrow d i (d_C__case_12 x18
    x17 x16 x3 l cd cs) (d_C__case_12 x18 x17 x16 x3 r cd cs)
  Dimacs.Curry_Types.Choices_C_Boolean d i xs -> narrows cs d i (\z ->
    d_C__case_12 x18 x17 x16 x3 z cd cs) xs
  Dimacs.Curry_Types.Guard_C_Boolean d c e -> guardCons d c ((\x -> d_C__case_12
    x18 x17 x16 x3 e cd x) $! addCs c cs)
  Dimacs.Curry_Types.Fail_C_Boolean d info -> failCons d (traceFail
    "Dimacs.Build._case_12" [show x18, show x17, show x16, show x3, show x4]
    info)
  _ -> failCons cd (consFail "Dimacs.Build._case_12" (showCons x4))

d_C__case_11 :: Curry_Prelude.OP_List Dimacs.Curry_Types.C_Boolean
  -> Dimacs.Curry_Types.C_Boolean -> Dimacs.Curry_Types.C_Boolean
  -> Dimacs.Curry_Types.C_Boolean -> Curry_Prelude.OP_List
  Dimacs.Curry_Types.C_Boolean -> Cover -> ConstStore
  -> Dimacs.Curry_Types.C_Boolean
d_C__case_11 x17 x4 x16 x3 x21 cd cs = case x21 of
  Curry_Prelude.OP_List -> Dimacs.Curry_Types.C_And Curry_Prelude.OP_List
  Curry_Prelude.OP_Cons x22 x23 -> d_C__case_10 x23 x4 x16 x22 x3 x17 cd cs
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (d_C__case_11 x17 x4 x16 x3
    l cd cs) (d_C__case_11 x17 x4 x16 x3 r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z -> d_C__case_11 x17
    x4 x16 x3 z cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c ((\x -> d_C__case_11 x17 x4
    x16 x3 e cd x) $! addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail
    "Dimacs.Build._case_11" [show x17, show x4, show x16, show x3, show x21]
    info)
  _ -> failCons cd (consFail "Dimacs.Build._case_11" (showCons x21))

d_C__case_10 :: Curry_Prelude.OP_List Dimacs.Curry_Types.C_Boolean
  -> Dimacs.Curry_Types.C_Boolean -> Dimacs.Curry_Types.C_Boolean
  -> Dimacs.Curry_Types.C_Boolean -> Dimacs.Curry_Types.C_Boolean
  -> Curry_Prelude.OP_List Dimacs.Curry_Types.C_Boolean -> Cover -> ConstStore
  -> Dimacs.Curry_Types.C_Boolean
d_C__case_10 x23 x4 x16 x22 x3 x17 cd cs = case x17 of
  Curry_Prelude.OP_List -> d_C_dist x16 x4 cd cs
  Curry_Prelude.OP_Cons x24 x25 -> d_C__case_9 x4 x17 x16 x22 x3 x23 cd cs
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (d_C__case_10 x23 x4 x16
    x22 x3 l cd cs) (d_C__case_10 x23 x4 x16 x22 x3 r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z -> d_C__case_10 x23
    x4 x16 x22 x3 z cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c ((\x -> d_C__case_10 x23 x4
    x16 x22 x3 e cd x) $! addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail
    "Dimacs.Build._case_10" [show x23, show x4, show x16, show x22, show x3
    , show x17] info)
  _ -> failCons cd (consFail "Dimacs.Build._case_10" (showCons x17))

d_C__case_9 :: Dimacs.Curry_Types.C_Boolean -> Curry_Prelude.OP_List
  Dimacs.Curry_Types.C_Boolean -> Dimacs.Curry_Types.C_Boolean
  -> Dimacs.Curry_Types.C_Boolean -> Dimacs.Curry_Types.C_Boolean
  -> Curry_Prelude.OP_List Dimacs.Curry_Types.C_Boolean -> Cover -> ConstStore
  -> Dimacs.Curry_Types.C_Boolean
d_C__case_9 x4 x17 x16 x22 x3 x23 cd cs = case x23 of
  Curry_Prelude.OP_List -> d_C_dist x3 x22 cd cs
  Curry_Prelude.OP_Cons x26 x27 -> Dimacs.Curry_Types.C_And
    (Curry_Prelude.OP_Cons (d_C_dist x16 x4 cd cs) (Curry_Prelude.OP_Cons
    (d_C_dist (Dimacs.Curry_Types.C_And x17) x4 cd cs) Curry_Prelude.OP_List))
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (d_C__case_9 x4 x17 x16 x22
    x3 l cd cs) (d_C__case_9 x4 x17 x16 x22 x3 r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z -> d_C__case_9 x4
    x17 x16 x22 x3 z cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c ((\x -> d_C__case_9 x4 x17
    x16 x22 x3 e cd x) $! addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail
    "Dimacs.Build._case_9" [show x4, show x17, show x16, show x22, show x3, show
    x23] info)
  _ -> failCons cd (consFail "Dimacs.Build._case_9" (showCons x23))

d_C__case_4 :: Curry_Prelude.OP_List Dimacs.Curry_Types.C_Boolean
  -> Curry_Prelude.OP_List Dimacs.Curry_Types.C_Boolean
  -> Dimacs.Curry_Types.C_Boolean -> Cover -> ConstStore
  -> Curry_Prelude.OP_List Dimacs.Curry_Types.C_Boolean
d_C__case_4 x4 x3 x2 cd cs = case x2 of
  Dimacs.Curry_Types.C_And x5 -> d_C_flattenAnd (Curry_Prelude.d_OP_plus_plus x5
    x3 cd cs) cd cs
  Dimacs.Curry_Types.C_Var x6 -> x4
  Dimacs.Curry_Types.C_Not x7 -> x4
  Dimacs.Curry_Types.C_Or x8 -> x4
  Dimacs.Curry_Types.Choice_C_Boolean d i l r -> narrow d i (d_C__case_4 x4 x3 l
    cd cs) (d_C__case_4 x4 x3 r cd cs)
  Dimacs.Curry_Types.Choices_C_Boolean d i xs -> narrows cs d i (\z ->
    d_C__case_4 x4 x3 z cd cs) xs
  Dimacs.Curry_Types.Guard_C_Boolean d c e -> guardCons d c ((\x -> d_C__case_4
    x4 x3 e cd x) $! addCs c cs)
  Dimacs.Curry_Types.Fail_C_Boolean d info -> failCons d (traceFail
    "Dimacs.Build._case_4" [show x4, show x3, show x2] info)
  _ -> failCons cd (consFail "Dimacs.Build._case_4" (showCons x2))

d_C__case_3 :: Curry_Prelude.OP_List Dimacs.Curry_Types.C_Boolean
  -> Curry_Prelude.OP_List Dimacs.Curry_Types.C_Boolean
  -> Dimacs.Curry_Types.C_Boolean -> Cover -> ConstStore
  -> Curry_Prelude.OP_List Dimacs.Curry_Types.C_Boolean
d_C__case_3 x4 x3 x2 cd cs = case x2 of
  Dimacs.Curry_Types.C_Or x5 -> d_C_flattenOr (Curry_Prelude.d_OP_plus_plus x5
    x3 cd cs) cd cs
  Dimacs.Curry_Types.C_Var x6 -> x4
  Dimacs.Curry_Types.C_Not x7 -> x4
  Dimacs.Curry_Types.C_And x8 -> x4
  Dimacs.Curry_Types.Choice_C_Boolean d i l r -> narrow d i (d_C__case_3 x4 x3 l
    cd cs) (d_C__case_3 x4 x3 r cd cs)
  Dimacs.Curry_Types.Choices_C_Boolean d i xs -> narrows cs d i (\z ->
    d_C__case_3 x4 x3 z cd cs) xs
  Dimacs.Curry_Types.Guard_C_Boolean d c e -> guardCons d c ((\x -> d_C__case_3
    x4 x3 e cd x) $! addCs c cs)
  Dimacs.Curry_Types.Fail_C_Boolean d info -> failCons d (traceFail
    "Dimacs.Build._case_3" [show x4, show x3, show x2] info)
  _ -> failCons cd (consFail "Dimacs.Build._case_3" (showCons x2))

d_C__case_2 :: Curry_Prelude.C_Bool -> Dimacs.Curry_Types.C_Boolean -> Cover
  -> ConstStore -> Curry_Prelude.C_Bool
d_C__case_2 x2 x1 cd cs = case x1 of
  Dimacs.Curry_Types.C_Or x3 -> d_OP_isTaut_dot_isTaut_tick_dot_198 x3 cd cs
  Dimacs.Curry_Types.C_Var x4 -> x2
  Dimacs.Curry_Types.C_Not x5 -> x2
  Dimacs.Curry_Types.C_And x6 -> x2
  Dimacs.Curry_Types.Choice_C_Boolean d i l r -> narrow d i (d_C__case_2 x2 l cd
    cs) (d_C__case_2 x2 r cd cs)
  Dimacs.Curry_Types.Choices_C_Boolean d i xs -> narrows cs d i (\z ->
    d_C__case_2 x2 z cd cs) xs
  Dimacs.Curry_Types.Guard_C_Boolean d c e -> guardCons d c ((\x -> d_C__case_2
    x2 e cd x) $! addCs c cs)
  Dimacs.Curry_Types.Fail_C_Boolean d info -> failCons d (traceFail
    "Dimacs.Build._case_2" [show x2, show x1] info)
  _ -> failCons cd (consFail "Dimacs.Build._case_2" (showCons x1))

d_C__case_1 :: Curry_Prelude.C_Bool -> Curry_Prelude.OP_List
  Dimacs.Curry_Types.C_Boolean -> Dimacs.Curry_Types.C_Boolean -> Cover
  -> ConstStore -> Curry_Prelude.C_Bool
d_C__case_1 x3 x2 x1 cd cs = case x1 of
  Dimacs.Curry_Types.C_Var x4 -> Curry_Prelude.d_C_apply (Curry_Prelude.d_C_elem
    Dimacs.Curry_Types.d_OP_uscore_inst_hash_Prelude_dot_Eq_hash_Dimacs_dot_Types_dot_Boolean_hash
    (Curry_Prelude.d_C_apply (d_C_nv cd cs) x4 cd cs) cd cs) x2 cd cs
  Dimacs.Curry_Types.C_Not x5 -> let x6 = Curry_Prelude.C_False
    in d_C__case_0 x6 x2 x5 cd cs
  Dimacs.Curry_Types.C_And x11 -> x3
  Dimacs.Curry_Types.C_Or x12 -> x3
  Dimacs.Curry_Types.Choice_C_Boolean d i l r -> narrow d i (d_C__case_1 x3 x2 l
    cd cs) (d_C__case_1 x3 x2 r cd cs)
  Dimacs.Curry_Types.Choices_C_Boolean d i xs -> narrows cs d i (\z ->
    d_C__case_1 x3 x2 z cd cs) xs
  Dimacs.Curry_Types.Guard_C_Boolean d c e -> guardCons d c ((\x -> d_C__case_1
    x3 x2 e cd x) $! addCs c cs)
  Dimacs.Curry_Types.Fail_C_Boolean d info -> failCons d (traceFail
    "Dimacs.Build._case_1" [show x3, show x2, show x1] info)
  _ -> failCons cd (consFail "Dimacs.Build._case_1" (showCons x1))

d_C__case_0 :: Curry_Prelude.C_Bool -> Curry_Prelude.OP_List
  Dimacs.Curry_Types.C_Boolean -> Dimacs.Curry_Types.C_Boolean -> Cover
  -> ConstStore -> Curry_Prelude.C_Bool
d_C__case_0 x6 x2 x5 cd cs = case x5 of
  Dimacs.Curry_Types.C_Var x7 -> Curry_Prelude.d_C_apply (Curry_Prelude.d_C_elem
    Dimacs.Curry_Types.d_OP_uscore_inst_hash_Prelude_dot_Eq_hash_Dimacs_dot_Types_dot_Boolean_hash
    (Curry_Prelude.d_C_apply (d_C_va cd cs) x7 cd cs) cd cs) x2 cd cs
  Dimacs.Curry_Types.C_Not x8 -> x6
  Dimacs.Curry_Types.C_And x9 -> x6
  Dimacs.Curry_Types.C_Or x10 -> x6
  Dimacs.Curry_Types.Choice_C_Boolean d i l r -> narrow d i (d_C__case_0 x6 x2 l
    cd cs) (d_C__case_0 x6 x2 r cd cs)
  Dimacs.Curry_Types.Choices_C_Boolean d i xs -> narrows cs d i (\z ->
    d_C__case_0 x6 x2 z cd cs) xs
  Dimacs.Curry_Types.Guard_C_Boolean d c e -> guardCons d c ((\x -> d_C__case_0
    x6 x2 e cd x) $! addCs c cs)
  Dimacs.Curry_Types.Fail_C_Boolean d info -> failCons d (traceFail
    "Dimacs.Build._case_0" [show x6, show x2, show x5] info)
  _ -> failCons cd (consFail "Dimacs.Build._case_0" (showCons x5))

