{-# LANGUAGE MagicHash #-}
{-# LANGUAGE ScopedTypeVariables #-}
{-# LANGUAGE QuantifiedConstraints #-}
{-# LANGUAGE RankNTypes #-}
{-# LANGUAGE PolyKinds #-}
{-# LANGUAGE MultiParamTypeClasses #-}
{-# LANGUAGE FlexibleInstances #-}
{-# LANGUAGE CPP #-}
{-# OPTIONS_GHC -fno-warn-overlapping-patterns #-}
{-# OPTIONS_GHC -fno-warn-missing-methods #-}
#if __GLASGOW_HASKELL__ >= 800
{-# OPTIONS_GHC -fno-warn-redundant-constraints #-}
#else
{-# OPTIONS_GHC -fno-warn-duplicate-constraints #-}
#endif

module JSON.Curry_Pretty ( d_C_ppJSON, d_C_ppJValue, nd_C_ppJValue ) where

import Basics
import qualified Data.Curry_Char
import qualified JSON.Curry_Data
import qualified Curry_Prelude
import qualified Text.Curry_Pretty
import qualified Text.Curry_PrettyImpl


d_C_ppJSON :: JSON.Curry_Data.C_JValue -> Cover -> ConstStore
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C_ppJSON x1 cd cs = Curry_Prelude.d_C_apply (Text.Curry_Pretty.d_C_pPrint cd
  cs) (d_C_ppJValue x1 cd cs) cd cs

d_C_ppJValue :: JSON.Curry_Data.C_JValue -> Cover -> ConstStore
  -> Text.Curry_PrettyImpl.C_Doc
d_C_ppJValue x1 cd cs = case x1 of
  JSON.Curry_Data.C_JBool x2 -> Text.Curry_Pretty.d_C_text (d_C__case_9 x2 cd
    cs) cd cs
  JSON.Curry_Data.C_JNull -> Text.Curry_Pretty.d_C_text
    (Curry_Prelude.toCurryString "null") cd cs
  JSON.Curry_Data.C_JInt x3 -> Text.Curry_Pretty.d_C_int x3 cd cs
  JSON.Curry_Data.C_JNumber x4 -> Text.Curry_Pretty.d_C_float x4 cd cs
  JSON.Curry_Data.C_JString x5 -> Curry_Prelude.d_OP_dollar
    Text.Curry_Pretty.d_C_text (d_C_showJSONString x5 cd cs) cd cs
  JSON.Curry_Data.C_JArray x6 -> d_C_ppJArray x6 cd cs
  JSON.Curry_Data.C_JObject x7 -> d_C_ppJObject (JSON.Curry_Data.d_C_fromJObject
    x7 cd cs) cd cs
  JSON.Curry_Data.Choice_C_JValue d i l r -> narrow d i (d_C_ppJValue l cd cs)
    (d_C_ppJValue r cd cs)
  JSON.Curry_Data.Choices_C_JValue d i xs -> narrows cs d i (\z -> d_C_ppJValue
    z cd cs) xs
  JSON.Curry_Data.Guard_C_JValue d c e -> guardCons d c ((\x -> d_C_ppJValue e
    cd x) $! addCs c cs)
  JSON.Curry_Data.Fail_C_JValue d info -> failCons d (traceFail
    "JSON.Pretty.ppJValue" [show x1] info)
  _ -> failCons cd (consFail "JSON.Pretty.ppJValue" (showCons x1))

nd_C_ppJValue :: JSON.Curry_Data.C_JValue -> IDSupply -> Cover -> ConstStore
  -> Text.Curry_PrettyImpl.C_Doc
nd_C_ppJValue x1 s cd cs = case x1 of
  JSON.Curry_Data.C_JBool x2 -> let s0 = s
    in s0 `seq` Text.Curry_Pretty.nd_C_text (d_C__case_9 x2 cd cs) s0 cd cs
  JSON.Curry_Data.C_JNull -> let s0 = s
    in s0 `seq` Text.Curry_Pretty.nd_C_text (Curry_Prelude.toCurryString "null")
    s0 cd cs
  JSON.Curry_Data.C_JInt x3 -> let s0 = s
    in s0 `seq` Text.Curry_Pretty.nd_C_int x3 s0 cd cs
  JSON.Curry_Data.C_JNumber x4 -> let s0 = s
    in s0 `seq` Text.Curry_Pretty.nd_C_float x4 s0 cd cs
  JSON.Curry_Data.C_JString x5 -> let s0 = s
    in s0 `seq` Curry_Prelude.nd_OP_dollar (wrapNX id
    Text.Curry_Pretty.nd_C_text) (d_C_showJSONString x5 cd cs) s0 cd cs
  JSON.Curry_Data.C_JArray x6 -> let s0 = s
    in s0 `seq` nd_C_ppJArray x6 s0 cd cs
  JSON.Curry_Data.C_JObject x7 -> let s0 = s
    in s0 `seq` nd_C_ppJObject (JSON.Curry_Data.d_C_fromJObject x7 cd cs) s0 cd
    cs
  JSON.Curry_Data.Choice_C_JValue d i l r -> narrow d i (nd_C_ppJValue l s cd
    cs) (nd_C_ppJValue r s cd cs)
  JSON.Curry_Data.Choices_C_JValue d i xs -> narrows cs d i (\z -> nd_C_ppJValue
    z s cd cs) xs
  JSON.Curry_Data.Guard_C_JValue d c e -> guardCons d c ((\x -> nd_C_ppJValue e
    s cd x) $! addCs c cs)
  JSON.Curry_Data.Fail_C_JValue d info -> failCons d (traceFail
    "JSON.Pretty.ppJValue" [show x1] info)
  _ -> failCons cd (consFail "JSON.Pretty.ppJValue" (showCons x1))

d_C_ppJArray :: Curry_Prelude.OP_List JSON.Curry_Data.C_JValue -> Cover
  -> ConstStore -> Text.Curry_PrettyImpl.C_Doc
d_C_ppJArray x1 cd cs = Curry_Prelude.d_OP_dollar
  (Text.Curry_Pretty.d_C_listSpaced cd cs) (Curry_Prelude.d_C_map d_C_ppJValue
  x1 cd cs) cd cs

nd_C_ppJArray :: Curry_Prelude.OP_List JSON.Curry_Data.C_JValue -> IDSupply
  -> Cover -> ConstStore -> Text.Curry_PrettyImpl.C_Doc
nd_C_ppJArray x1 s cd cs = let s3 = s
  in s3 `seq` (let s2 = leftSupply s3
                   s4 = rightSupply s3
                   s0 = leftSupply s4
                   s1 = rightSupply s4
  in s2 `seq` (s4 `seq` (s0 `seq` (s1 `seq` Curry_Prelude.nd_OP_dollar
  (Text.Curry_Pretty.nd_C_listSpaced s0 cd cs) (Curry_Prelude.nd_C_map (wrapNX
  id nd_C_ppJValue) x1 s1 cd cs) s2 cd cs))))

d_C_ppJObject :: Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) JSON.Curry_Data.C_JValue)
  -> Cover -> ConstStore -> Text.Curry_PrettyImpl.C_Doc
d_C_ppJObject x1 cd cs = Curry_Prelude.d_C_apply (Curry_Prelude.d_C_apply
  (Text.Curry_Pretty.d_OP_dollar_dollar cd cs) (Curry_Prelude.d_OP_dollar
  (Text.Curry_Pretty.d_C_nest (Curry_Prelude.C_Int (2)))
  (Curry_Prelude.d_C_apply (Curry_Prelude.d_C_apply
  (Text.Curry_Pretty.d_OP_dollar_dollar cd cs) (Text.Curry_Pretty.d_C_lbrace cd
  cs) cd cs) (Curry_Prelude.d_C_apply (Text.Curry_Pretty.d_C_vsep cd cs)
  (Curry_Prelude.d_OP_dollar (Text.Curry_Pretty.d_C_punctuate
  (Text.Curry_Pretty.d_C_comma cd cs)) (Curry_Prelude.d_C_map
  (d_OP_ppJObject_dot_ppKVP_dot_20
  (Curry_Prelude.d_OP_uscore_inst_hash_Prelude_dot_Show_hash_lbracket_rbracket_hash_0_hash_hash
  Curry_Prelude.d_OP_uscore_inst_hash_Prelude_dot_Show_hash_Prelude_dot_Char_hash))
  x1 cd cs) cd cs) cd cs) cd cs) cd cs) cd cs) (Text.Curry_Pretty.d_C_rbrace cd
  cs) cd cs

nd_C_ppJObject :: Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) JSON.Curry_Data.C_JValue)
  -> IDSupply -> Cover -> ConstStore -> Text.Curry_PrettyImpl.C_Doc
nd_C_ppJObject x1 s cd cs = let s25 = s
  in s25 `seq` (let s24 = leftSupply s25
                    s26 = rightSupply s25
                    s21 = leftSupply s26
                    s23 = rightSupply s26
  in s24 `seq` (s26 `seq` (s21 `seq` (s23 `seq` Curry_Prelude.nd_C_apply
  (let s20 = leftSupply s21
       s22 = rightSupply s21
       s0 = leftSupply s22
       s19 = rightSupply s22
  in s20 `seq` (s22 `seq` (s0 `seq` (s19 `seq` Curry_Prelude.nd_C_apply
  (Text.Curry_Pretty.nd_OP_dollar_dollar s0 cd cs) (let s18 = leftSupply s19
                                                        s16 = rightSupply s19
  in s18 `seq` (s16 `seq` Curry_Prelude.nd_OP_dollar (wrapNX id
  (Text.Curry_Pretty.nd_C_nest (Curry_Prelude.C_Int (2)))) (let s15 = leftSupply
                                                                  s16
                                                                s17 = rightSupply
                                                                  s16
                                                                s4 = leftSupply
                                                                  s17
                                                                s13 = rightSupply
                                                                  s17
  in s15 `seq` (s17 `seq` (s4 `seq` (s13 `seq` Curry_Prelude.nd_C_apply
  (let s3 = leftSupply s4
       s5 = rightSupply s4
       s1 = leftSupply s5
       s2 = rightSupply s5
  in s3 `seq` (s5 `seq` (s1 `seq` (s2 `seq` Curry_Prelude.nd_C_apply
  (Text.Curry_Pretty.nd_OP_dollar_dollar s1 cd cs)
  (Text.Curry_Pretty.nd_C_lbrace s2 cd cs) s3 cd cs)))) (let s12 = leftSupply
                                                               s13
                                                             s14 = rightSupply
                                                               s13
                                                             s6 = leftSupply s14
                                                             s10 = rightSupply
                                                               s14
  in s12 `seq` (s14 `seq` (s6 `seq` (s10 `seq` Curry_Prelude.nd_C_apply
  (Text.Curry_Pretty.nd_C_vsep s6 cd cs) (let s9 = leftSupply s10
                                              s11 = rightSupply s10
                                              s7 = leftSupply s11
                                              s8 = rightSupply s11
  in s9 `seq` (s11 `seq` (s7 `seq` (s8 `seq` Curry_Prelude.nd_OP_dollar (wrapNX
  id (Text.Curry_Pretty.nd_C_punctuate (Text.Curry_Pretty.nd_C_comma s7 cd cs)))
  (Curry_Prelude.nd_C_map (wrapNX id (nd_OP_ppJObject_dot_ppKVP_dot_20 (wrapNX
  id
  (Curry_Prelude.nd_OP_uscore_inst_hash_Prelude_dot_Show_hash_lbracket_rbracket_hash_0_hash_hash
  (wrapNX id
  Curry_Prelude.nd_OP_uscore_inst_hash_Prelude_dot_Show_hash_Prelude_dot_Char_hash)))))
  x1 s8 cd cs) s9 cd cs)))) s12 cd cs)))) s15 cd cs)))) s18 cd cs)) s20 cd
  cs)))) (Text.Curry_Pretty.nd_C_rbrace s23 cd cs) s24 cd cs))))

d_OP_ppJObject_dot_ppKVP_dot_20 :: forall t0 . (Curry_Prelude.Curry
  t0) => (Curry_Prelude.OP_Unit -> Cover -> ConstStore
  -> Curry_Prelude.OP_uscore_Dict_hash_Show t0) -> Curry_Prelude.OP_Tuple2 t0
  JSON.Curry_Data.C_JValue -> Cover -> ConstStore -> Text.Curry_PrettyImpl.C_Doc
d_OP_ppJObject_dot_ppKVP_dot_20 x1 x2 cd cs = case x2 of
  Curry_Prelude.OP_Tuple2 x3 x4 -> Curry_Prelude.d_C_apply
    (Curry_Prelude.d_C_apply (Text.Curry_Pretty.d_OP_lt_plus_gt cd cs)
    (Text.Curry_Pretty.d_OP_lt_gt (Curry_Prelude.d_OP_dollar
    Text.Curry_Pretty.d_C_text (Curry_Prelude.d_C_apply (Curry_Prelude.d_C_show
    x1 cd cs) x3 cd cs) cd cs) (Text.Curry_Pretty.d_C_colon cd cs) cd cs) cd cs)
    (d_C_ppJValue x4 cd cs) cd cs
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (d_OP_ppJObject_dot_ppKVP_dot_20 x1 l cd cs)
    (d_OP_ppJObject_dot_ppKVP_dot_20 x1 r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    d_OP_ppJObject_dot_ppKVP_dot_20 x1 z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c ((\x ->
    d_OP_ppJObject_dot_ppKVP_dot_20 x1 e cd x) $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "JSON.Pretty.ppJObject.ppKVP.20" [show x1, show x2] info)
  _ -> failCons cd (consFail "JSON.Pretty.ppJObject.ppKVP.20" (showCons x2))

nd_OP_ppJObject_dot_ppKVP_dot_20 :: forall t0 . (Curry_Prelude.Curry t0) => Func
  Curry_Prelude.OP_Unit (Curry_Prelude.OP_uscore_Dict_hash_Show t0)
  -> Curry_Prelude.OP_Tuple2 t0 JSON.Curry_Data.C_JValue -> IDSupply -> Cover
  -> ConstStore -> Text.Curry_PrettyImpl.C_Doc
nd_OP_ppJObject_dot_ppKVP_dot_20 x1 x2 s cd cs = case x2 of
  Curry_Prelude.OP_Tuple2 x3 x4 -> let s15 = s
    in s15 `seq` (let s14 = leftSupply s15
                      s16 = rightSupply s15
                      s11 = leftSupply s16
                      s13 = rightSupply s16
    in s14 `seq` (s16 `seq` (s11 `seq` (s13 `seq` Curry_Prelude.nd_C_apply
    (let s10 = leftSupply s11
         s12 = rightSupply s11
         s0 = leftSupply s12
         s8 = rightSupply s12
    in s10 `seq` (s12 `seq` (s0 `seq` (s8 `seq` Curry_Prelude.nd_C_apply
    (Text.Curry_Pretty.nd_OP_lt_plus_gt s0 cd cs) (let s7 = leftSupply s8
                                                       s9 = rightSupply s8
                                                       s5 = leftSupply s9
                                                       s6 = rightSupply s9
    in s7 `seq` (s9 `seq` (s5 `seq` (s6 `seq` Text.Curry_Pretty.nd_OP_lt_gt
    (let s4 = leftSupply s5
         s3 = rightSupply s5
    in s4 `seq` (s3 `seq` Curry_Prelude.nd_OP_dollar (wrapNX id
    Text.Curry_Pretty.nd_C_text) (let s2 = leftSupply s3
                                      s1 = rightSupply s3
    in s2 `seq` (s1 `seq` Curry_Prelude.nd_C_apply (Curry_Prelude.nd_C_show x1
    s1 cd cs) x3 s2 cd cs)) s4 cd cs)) (Text.Curry_Pretty.nd_C_colon s6 cd cs)
    s7 cd cs)))) s10 cd cs)))) (nd_C_ppJValue x4 s13 cd cs) s14 cd cs))))
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (nd_OP_ppJObject_dot_ppKVP_dot_20 x1 l s cd cs)
    (nd_OP_ppJObject_dot_ppKVP_dot_20 x1 r s cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    nd_OP_ppJObject_dot_ppKVP_dot_20 x1 z s cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c ((\x ->
    nd_OP_ppJObject_dot_ppKVP_dot_20 x1 e s cd x) $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "JSON.Pretty.ppJObject.ppKVP.20" [show x1, show x2] info)
  _ -> failCons cd (consFail "JSON.Pretty.ppJObject.ppKVP.20" (showCons x2))

d_C_showJSONString :: Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover
  -> ConstStore -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C_showJSONString x1 cd cs = Curry_Prelude.OP_Cons (Curry_Prelude.C_Char '"'#)
  (Curry_Prelude.d_OP_plus_plus (Curry_Prelude.d_C_apply
  (Curry_Prelude.d_C_concatMap d_OP_showJSONString_dot_showJChar_dot_24 cd cs)
  x1 cd cs) (Curry_Prelude.toCurryString "\"") cd cs)

d_OP_showJSONString_dot_showHex4_dot_24 :: Curry_Prelude.C_Int -> Cover
  -> ConstStore -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_OP_showJSONString_dot_showHex4_dot_24 x1 cd cs = Curry_Prelude.d_C_map
  (d_OP_showJSONString_dot_showHex4_dot_24_dot_uscore_hash_lambda1 x1)
  (Curry_Prelude.OP_Cons (Curry_Prelude.C_Int (4096)) (Curry_Prelude.OP_Cons
  (Curry_Prelude.C_Int (256)) (Curry_Prelude.OP_Cons (Curry_Prelude.C_Int (16))
  (Curry_Prelude.OP_Cons (Curry_Prelude.C_Int (1)) Curry_Prelude.OP_List)))) cd
  cs

d_OP_showJSONString_dot_showHex4_dot_24_dot_uscore_hash_lambda1 :: Curry_Prelude.C_Int
  -> Curry_Prelude.C_Int -> Cover -> ConstStore -> Curry_Prelude.C_Char
d_OP_showJSONString_dot_showHex4_dot_24_dot_uscore_hash_lambda1 x1 x2 cd cs =
  Data.Curry_Char.d_C_intToDigit (Curry_Prelude.d_C_apply
  (Curry_Prelude.d_C_apply
  (Curry_Prelude.d_OP_uscore_impl_hash_mod_hash_Prelude_dot_Integral_hash_Prelude_dot_Int_hash
  cd cs) (Curry_Prelude.d_C_apply (Curry_Prelude.d_C_apply
  (Curry_Prelude.d_OP_uscore_impl_hash_div_hash_Prelude_dot_Integral_hash_Prelude_dot_Int_hash
  cd cs) x1 cd cs) x2 cd cs) cd cs) (Curry_Prelude.C_Int (16)) cd cs) cd cs

d_OP_showJSONString_dot_showJChar_dot_24 :: Curry_Prelude.C_Char -> Cover
  -> ConstStore -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_OP_showJSONString_dot_showJChar_dot_24 x1 cd cs = d_C__case_8 x1
  (Curry_Prelude.d_OP_uscore_impl_hash_eq_eq_hash_Prelude_dot_Eq_hash_Prelude_dot_Char_hash
  x1 (Curry_Prelude.C_Char '"'#) cd cs) cd cs

d_C__case_9 :: Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C__case_9 x2 cd cs = case x2 of
  Curry_Prelude.C_True -> Curry_Prelude.toCurryString "true"
  Curry_Prelude.C_False -> Curry_Prelude.toCurryString "false"
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_9 l cd cs)
    (d_C__case_9 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_9 z cd
    cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c ((\x -> d_C__case_9 e cd
    x) $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "JSON.Pretty._case_9" [show x2] info)
  _ -> failCons cd (consFail "JSON.Pretty._case_9" (showCons x2))

d_C__case_8 :: Curry_Prelude.C_Char -> Curry_Prelude.C_Bool -> Cover
  -> ConstStore -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C__case_8 x1 x2 cd cs = case x2 of
  Curry_Prelude.C_True -> Curry_Prelude.toCurryString "\\\""
  Curry_Prelude.C_False -> d_C__case_7 x1
    (Curry_Prelude.d_OP_uscore_impl_hash_eq_eq_hash_Prelude_dot_Eq_hash_Prelude_dot_Char_hash
    x1 (Curry_Prelude.C_Char '\\'#) cd cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_8 x1 l cd cs)
    (d_C__case_8 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_8 x1 z
    cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c ((\x -> d_C__case_8 x1 e cd
    x) $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "JSON.Pretty._case_8" [show x1, show x2] info)
  _ -> failCons cd (consFail "JSON.Pretty._case_8" (showCons x2))

d_C__case_7 :: Curry_Prelude.C_Char -> Curry_Prelude.C_Bool -> Cover
  -> ConstStore -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C__case_7 x1 x2 cd cs = case x2 of
  Curry_Prelude.C_True -> Curry_Prelude.toCurryString "\\\\"
  Curry_Prelude.C_False -> d_C__case_6 x1
    (Curry_Prelude.d_OP_uscore_impl_hash_eq_eq_hash_Prelude_dot_Eq_hash_Prelude_dot_Char_hash
    x1 (Curry_Prelude.C_Char '\b'#) cd cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_7 x1 l cd cs)
    (d_C__case_7 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_7 x1 z
    cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c ((\x -> d_C__case_7 x1 e cd
    x) $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "JSON.Pretty._case_7" [show x1, show x2] info)
  _ -> failCons cd (consFail "JSON.Pretty._case_7" (showCons x2))

d_C__case_6 :: Curry_Prelude.C_Char -> Curry_Prelude.C_Bool -> Cover
  -> ConstStore -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C__case_6 x1 x2 cd cs = case x2 of
  Curry_Prelude.C_True -> Curry_Prelude.toCurryString "\\b"
  Curry_Prelude.C_False -> d_C__case_5 x1
    (Curry_Prelude.d_OP_uscore_impl_hash_eq_eq_hash_Prelude_dot_Eq_hash_Prelude_dot_Char_hash
    x1 (Curry_Prelude.C_Char '\f'#) cd cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_6 x1 l cd cs)
    (d_C__case_6 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_6 x1 z
    cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c ((\x -> d_C__case_6 x1 e cd
    x) $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "JSON.Pretty._case_6" [show x1, show x2] info)
  _ -> failCons cd (consFail "JSON.Pretty._case_6" (showCons x2))

d_C__case_5 :: Curry_Prelude.C_Char -> Curry_Prelude.C_Bool -> Cover
  -> ConstStore -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C__case_5 x1 x2 cd cs = case x2 of
  Curry_Prelude.C_True -> Curry_Prelude.toCurryString "\\f"
  Curry_Prelude.C_False -> d_C__case_4 x1
    (Curry_Prelude.d_OP_uscore_impl_hash_eq_eq_hash_Prelude_dot_Eq_hash_Prelude_dot_Char_hash
    x1 (Curry_Prelude.C_Char '\n'#) cd cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_5 x1 l cd cs)
    (d_C__case_5 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_5 x1 z
    cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c ((\x -> d_C__case_5 x1 e cd
    x) $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "JSON.Pretty._case_5" [show x1, show x2] info)
  _ -> failCons cd (consFail "JSON.Pretty._case_5" (showCons x2))

d_C__case_4 :: Curry_Prelude.C_Char -> Curry_Prelude.C_Bool -> Cover
  -> ConstStore -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C__case_4 x1 x2 cd cs = case x2 of
  Curry_Prelude.C_True -> Curry_Prelude.toCurryString "\\n"
  Curry_Prelude.C_False -> d_C__case_3 x1
    (Curry_Prelude.d_OP_uscore_impl_hash_eq_eq_hash_Prelude_dot_Eq_hash_Prelude_dot_Char_hash
    x1 (Curry_Prelude.C_Char '\r'#) cd cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_4 x1 l cd cs)
    (d_C__case_4 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_4 x1 z
    cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c ((\x -> d_C__case_4 x1 e cd
    x) $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "JSON.Pretty._case_4" [show x1, show x2] info)
  _ -> failCons cd (consFail "JSON.Pretty._case_4" (showCons x2))

d_C__case_3 :: Curry_Prelude.C_Char -> Curry_Prelude.C_Bool -> Cover
  -> ConstStore -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C__case_3 x1 x2 cd cs = case x2 of
  Curry_Prelude.C_True -> Curry_Prelude.toCurryString "\\r"
  Curry_Prelude.C_False -> d_C__case_2 x1
    (Curry_Prelude.d_OP_uscore_impl_hash_eq_eq_hash_Prelude_dot_Eq_hash_Prelude_dot_Char_hash
    x1 (Curry_Prelude.C_Char '\t'#) cd cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_3 x1 l cd cs)
    (d_C__case_3 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_3 x1 z
    cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c ((\x -> d_C__case_3 x1 e cd
    x) $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "JSON.Pretty._case_3" [show x1, show x2] info)
  _ -> failCons cd (consFail "JSON.Pretty._case_3" (showCons x2))

d_C__case_2 :: Curry_Prelude.C_Char -> Curry_Prelude.C_Bool -> Cover
  -> ConstStore -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C__case_2 x1 x2 cd cs = case x2 of
  Curry_Prelude.C_True -> Curry_Prelude.toCurryString "\\t"
  Curry_Prelude.C_False -> d_C__case_1 x1 (Curry_Prelude.d_OP_bar_bar
    (Curry_Prelude.d_C_apply (Curry_Prelude.d_C_apply
    (Curry_Prelude.d_OP_uscore_impl_hash_lt_hash_Prelude_dot_Ord_hash_Prelude_dot_Int_hash
    cd cs) (Curry_Prelude.d_C_ord x1 cd cs) cd cs) (Curry_Prelude.C_Int (32)) cd
    cs) (Curry_Prelude.d_C_apply (Curry_Prelude.d_C_apply
    (Curry_Prelude.d_OP_uscore_impl_hash_gt_hash_Prelude_dot_Ord_hash_Prelude_dot_Int_hash
    cd cs) (Curry_Prelude.d_C_ord x1 cd cs) cd cs) (Curry_Prelude.C_Int (126))
    cd cs) cd cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_2 x1 l cd cs)
    (d_C__case_2 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_2 x1 z
    cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c ((\x -> d_C__case_2 x1 e cd
    x) $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "JSON.Pretty._case_2" [show x1, show x2] info)
  _ -> failCons cd (consFail "JSON.Pretty._case_2" (showCons x2))

d_C__case_1 :: Curry_Prelude.C_Char -> Curry_Prelude.C_Bool -> Cover
  -> ConstStore -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C__case_1 x1 x2 cd cs = case x2 of
  Curry_Prelude.C_True -> Curry_Prelude.d_OP_plus_plus
    (Curry_Prelude.toCurryString "\\u") (d_OP_showJSONString_dot_showHex4_dot_24
    (Curry_Prelude.d_C_ord x1 cd cs) cd cs) cd cs
  Curry_Prelude.C_False -> d_C__case_0 x1 (Curry_Prelude.d_C_otherwise cd cs) cd
    cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_1 x1 l cd cs)
    (d_C__case_1 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_1 x1 z
    cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c ((\x -> d_C__case_1 x1 e cd
    x) $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "JSON.Pretty._case_1" [show x1, show x2] info)
  _ -> failCons cd (consFail "JSON.Pretty._case_1" (showCons x2))

d_C__case_0 :: Curry_Prelude.C_Char -> Curry_Prelude.C_Bool -> Cover
  -> ConstStore -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C__case_0 x1 x2 cd cs = case x2 of
  Curry_Prelude.C_True -> Curry_Prelude.OP_Cons x1 Curry_Prelude.OP_List
  Curry_Prelude.C_False -> Curry_Prelude.d_C_failed cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_0 x1 l cd cs)
    (d_C__case_0 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_0 x1 z
    cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c ((\x -> d_C__case_0 x1 e cd
    x) $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "JSON.Pretty._case_0" [show x1, show x2] info)
  _ -> failCons cd (consFail "JSON.Pretty._case_0" (showCons x2))

