{-# LANGUAGE MagicHash #-}
{-# LANGUAGE ScopedTypeVariables #-}
{-# LANGUAGE QuantifiedConstraints #-}
{-# LANGUAGE RankNTypes #-}
{-# LANGUAGE PolyKinds #-}
{-# LANGUAGE MultiParamTypeClasses #-}
{-# LANGUAGE FlexibleInstances #-}
{-# LANGUAGE CPP #-}
{-# OPTIONS_GHC -fno-warn-overlapping-patterns #-}
{-# OPTIONS_GHC -fno-warn-missing-methods #-}
#if __GLASGOW_HASKELL__ >= 800
{-# OPTIONS_GHC -fno-warn-redundant-constraints #-}
#else
{-# OPTIONS_GHC -fno-warn-duplicate-constraints #-}
#endif
{-# LANGUAGE MultiParamTypeClasses, CPP #-}

module Network.Curry_Socket
  ( C_Socket (..)
  , d_C_listenOn
  , d_C_accept
  , d_C_waitForSocketAccept
  , d_C_close
  , d_C_connectToSocket
  , d_C_listenOnFresh )
  where

import Basics
import qualified Curry_Prelude
import qualified System.Curry_IO

import Control.Concurrent
import Control.Monad (when)
import System.IO
#if __GLASGOW_HASKELL__ < 780
import Network
#endif
import Network.Socket hiding (sClose)

d_C_listenOn :: Curry_Prelude.C_Int -> Cover -> ConstStore -> Curry_Prelude.C_IO
  C_Socket
d_C_listenOn x1 cd cs = Curry_Prelude.d_OP_dollar_hash d_C_prim_listenOn x1 cd
  cs

d_C_accept :: C_Socket -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List Curry_Prelude.C_Char)
  System.Curry_IO.C_Handle)
d_C_accept x1 cd cs = Curry_Prelude.d_OP_dollar_hash_hash d_C_prim_socketAccept
  x1 cd cs

d_C_waitForSocketAccept :: C_Socket -> Curry_Prelude.C_Int -> Cover
  -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe
  (Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List Curry_Prelude.C_Char)
  System.Curry_IO.C_Handle))
d_C_waitForSocketAccept x1 x2 cd cs = Curry_Prelude.d_OP_dollar_hash
  (Curry_Prelude.d_OP_dollar_hash_hash (acceptCs id
  d_C_prim_waitForSocketAccept) x1 cd cs) x2 cd cs

d_C_close :: C_Socket -> Cover -> ConstStore -> Curry_Prelude.C_IO
  Curry_Prelude.OP_Unit
d_C_close x1 cd cs = Curry_Prelude.d_OP_dollar_hash_hash d_C_prim_sClose x1 cd
  cs

d_C_connectToSocket :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.C_Int -> Cover -> ConstStore -> Curry_Prelude.C_IO
  System.Curry_IO.C_Handle
d_C_connectToSocket x1 x2 cd cs = Curry_Prelude.d_OP_dollar_hash
  (Curry_Prelude.d_OP_dollar_hash_hash (acceptCs id d_C_prim_connectToSocket) x1
  cd cs) x2 cd cs

d_C_prim_listenOn :: Curry_Prelude.C_Int -> Cover -> ConstStore
  -> Curry_Prelude.C_IO C_Socket
d_C_prim_listenOn x1 cd cs = external_d_C_prim_listenOn x1 cd cs

d_C_listenOnFresh :: Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.OP_Tuple2 Curry_Prelude.C_Int C_Socket)
d_C_listenOnFresh cd cs = external_d_C_listenOnFresh cd cs

d_C_prim_socketAccept :: C_Socket -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List Curry_Prelude.C_Char)
  System.Curry_IO.C_Handle)
d_C_prim_socketAccept x1 cd cs = external_d_C_prim_socketAccept x1 cd cs

d_C_prim_waitForSocketAccept :: C_Socket -> Curry_Prelude.C_Int -> Cover
  -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe
  (Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List Curry_Prelude.C_Char)
  System.Curry_IO.C_Handle))
d_C_prim_waitForSocketAccept x1 x2 cd cs = external_d_C_prim_waitForSocketAccept
  x1 x2 cd cs

d_C_prim_sClose :: C_Socket -> Cover -> ConstStore -> Curry_Prelude.C_IO
  Curry_Prelude.OP_Unit
d_C_prim_sClose x1 cd cs = external_d_C_prim_sClose x1 cd cs

d_C_prim_connectToSocket :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.C_Int -> Cover -> ConstStore -> Curry_Prelude.C_IO
  System.Curry_IO.C_Handle
d_C_prim_connectToSocket x1 x2 cd cs = external_d_C_prim_connectToSocket x1 x2
  cd cs

type C_Socket = PrimData Socket

-------------------------------------------------
#if __GLASGOW_HASKELL__ < 780

acceptOld ::  Socket -> IO (Handle, HostName, PortNumber)
acceptOld = Network.accept

instance ConvertCurryHaskell Curry_Prelude.C_Int PortID where
  toCurry (PortNumber i) = toCurry (toInteger i)
  fromCurry i = PortNumber (fromInteger (fromCurry i))

external_d_C_listenOnFresh :: Cover -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.OP_Tuple2 Curry_Prelude.C_Int C_Socket)
external_d_C_listenOnFresh _ _ = toCurry listenOnFreshPort
  where
  listenOnFreshPort :: IO (PortID,Socket)
  listenOnFreshPort = do
    s <- listenOn (PortNumber aNY_PORT)
    p <- socketPort s
    return (p,s)

-------------------------------------------------
#else
-------------------------------------------------

acceptOld ::  Socket -> IO (Handle, HostName, PortNumber)
acceptOld sock = do (s, peer) <- Network.Socket.accept sock
                    p <- socketPort s
                    h <- socketToHandle s ReadWriteMode
                    -- s is invalid after this point.
                    return (h, show peer, p)

listenOn :: PortNumber -> IO Socket
listenOn pn = do  
  -- AI_PASSIVE is needed when the address should be used for bind/listenOn
  -- AF_INET forces IPv4. This is crucial, because some
  -- systems crashed with the old Implementation that allowed IPv6
  -- As soon as IPv6 is needed, someone has to look into this issue again.
  let hints = defaultHints { addrFlags = [AI_PASSIVE], addrFamily = AF_INET }
  addr:_ <- getAddrInfo (Just hints) Nothing (Just (show pn))
  sock <- socket (addrFamily addr) (addrSocketType addr) (addrProtocol addr)
  setSocketOption sock ReuseAddr 1
  withFdSocket sock setCloseOnExecIfNeeded
  Network.Socket.bind sock (addrAddress addr)
  listen sock maxListenQueue
  return sock

sClose :: Socket -> IO ()
sClose = close

connectTo :: HostName -> PortNumber -> IO Handle
connectTo s a = do 
  -- for AF_INET see above
  let hints = defaultHints { addrFamily = AF_INET }
  addr:_ <- getAddrInfo (Just hints) (Just s) (Just (show a))
  sock <- socket (addrFamily addr) (addrSocketType addr) (addrProtocol addr)
  connect sock (addrAddress addr)
  socketToHandle sock ReadWriteMode

instance ConvertCurryHaskell Curry_Prelude.C_Int PortNumber where
  toCurry i = toCurry (toInteger i)
  fromCurry i = fromInteger (fromCurry i)

external_d_C_listenOnFresh :: Cover -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.OP_Tuple2 Curry_Prelude.C_Int C_Socket)
external_d_C_listenOnFresh _ _ = toCurry listenOnFreshPort
  where
  listenOnFreshPort :: IO (PortNumber,Socket)
  listenOnFreshPort = do
    s <- listenOn defaultPort
    p <- socketPort s
    return (p,s)
#endif
-------------------------------------------------

external_d_C_prim_listenOn :: Curry_Prelude.C_Int -> Cover -> ConstStore -> Curry_Prelude.C_IO C_Socket
external_d_C_prim_listenOn i _ _ = toCurry listenOn i


external_d_C_prim_socketAccept :: C_Socket
  -> Cover -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.OP_Tuple2 Curry_Prelude.C_String System.Curry_IO.C_Handle)
external_d_C_prim_socketAccept socket _ _ =
 toCurry (\s -> acceptOld s >>= \ (h,s,_) -> return (s,OneHandle h)) socket

external_d_C_prim_waitForSocketAccept :: C_Socket -> Curry_Prelude.C_Int
 -> Cover -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe (Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List Curry_Prelude.C_Char) System.Curry_IO.C_Handle))
external_d_C_prim_waitForSocketAccept s i _ _ = toCurry wait s i

wait :: Socket -> Int -> IO (Maybe (String, CurryHandle))
wait s t =
  if t < 0
  then acceptOld s >>= \ (h, s, _) -> return (Just (s, OneHandle h))
  else do
    mv <- newEmptyMVar
    tacc <- forkIO (acceptOld s >>= \ (h, s, _) ->
                    putMVar mv (Just (s, OneHandle h)))
    ttim <- forkIO (delay ((fromIntegral t :: Integer) * 1000)
                    >> putMVar mv Nothing)
    res <- takeMVar mv
    maybe (killThread tacc) (\_ -> killThread ttim) res
    return res

-- Like 'threadDelay', but not bounded by an 'Int'
delay :: Integer -> IO ()
delay time = do
  let maxWait = min time $ toInteger (maxBound :: Int)
  threadDelay $ fromInteger maxWait
  when (maxWait /= time) $ delay (time - maxWait)

external_d_C_prim_sClose :: C_Socket -> Cover -> ConstStore -> Curry_Prelude.C_IO Curry_Prelude.OP_Unit
external_d_C_prim_sClose s _ _ = toCurry sClose s

external_d_C_prim_connectToSocket :: Curry_Prelude.C_String -> Curry_Prelude.C_Int
                                  -> Cover -> ConstStore -> Curry_Prelude.C_IO System.Curry_IO.C_Handle
external_d_C_prim_connectToSocket str i _ _ =
  toCurry (\ s i -> connectTo s i >>= return . OneHandle) str i
